(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     66194,       1772]*)
(*NotebookOutlinePosition[    107768,       2912]*)
(*  CellTagsIndexPosition[    107365,       2896]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["AspectRatio", "Section"],

Cell[TextData[{
  "AspectRatio is an option for Show, Plot and other graphic functions.  This \
discussion is paraphrased from examples provided by Dave Park.  If \
AspectRatio is set to a number it specifies the height to width ratio of the \
resulting graphic.  If the AspectRatio is set to Automatic ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " sets the width and height so that objects will not be distorted.  Hence \
the next cell draws a circle so it looks like a circle."
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"circ", "=", 
        RowBox[{"Graphics", "[", 
          RowBox[{\({Circle[{2, 2}, 3]}\), ",", 
            StyleBox[\(AspectRatio \[Rule] Automatic\),
              FontColor->RGBColor[0.8, 0.2, 0.2]], ",", 
            "\[IndentingNewLine]", \(PlotRange \[Rule] {{\(-10\), 
                  10}, {\(-10\), 10}}\), 
            ",", \(Background \[Rule] RGBColor[0.982, 0.96, 0.93]\), 
            ",", \({Axes \[Rule] True}\)}], "\[IndentingNewLine]", "]"}]}], 
      ";"}], "\[IndentingNewLine]", \(Show[circ];\)}], "Input",
  GeneratedCell->False],

Cell["\<\
In the next cell the AspectRatio is 1/2.  The graphic is not only half as \
high as it is wide, but the scales along the axes are now also different, and \
the numbers are packed more closely together in the vertical direction.  Also \
the circle no longer looks like a circle because of this change of scale.\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Show", "[", 
        RowBox[{"circ", ",", 
          StyleBox[\(AspectRatio \[Rule] 1\/2\),
            FontColor->RGBColor[0.8, 0.2, 0.2]]}], "]"}], ";"}]], "Input",
  GeneratedCell->False],

Cell["\<\
In the next cell the graphic is twice as high as it is wide, and the scale is \
more compressed in the horizontal direction. In fact, some of the numbers \
overlap, but you can click on the graphic and drag it to a larger size to \
make it look better.  In this case the circle has been stretched vertically.  \
Of course the setting need not be written as a rational number.  You could \
just as well use AspectRatio\[Rule]2.\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Show", "[", 
        RowBox[{"circ", ",", 
          StyleBox[\(AspectRatio \[Rule] 2\/1\),
            FontColor->RGBColor[0.8, 0.2, 0.2]]}], "]"}], ";"}]], "Input",
  GeneratedCell->False],

Cell["\<\
The first cell below next cell makes a graphic where the height and width are \
equal.  This looks very much like the first plot.  However the circle might \
not look like a circle if a different PlotRange was used as in the second \
cell below.  The second cell below makes a square graphic, but the circle is \
stretched because of the PlotRange specified.\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Show", "[", 
        RowBox[{"circ", ",", 
          StyleBox[\(AspectRatio \[Rule] 1\),
            FontColor->RGBColor[0.8, 0.2, 0.2]]}], "]"}], ";"}]], "Input",
  GeneratedCell->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"Show", "[", 
        RowBox[{"circ", ",", 
          StyleBox[\(AspectRatio \[Rule] 1\),
            FontColor->RGBColor[0.808606, 0.265629, 0.187503]], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{\({\(-10\), 10}\), ",", 
                StyleBox[\({\(-5\), 5}\),
                  FontColor->RGBColor[0.8, 0.2, 0.2]]}], "}"}]}]}], "]"}], 
      ";"}]], "Input",
  GeneratedCell->False],

Cell["\<\
Setting AspectRatio to Automatic will always make the scales along the two \
axes the same and adjusts the length to width ratio as required.  Using \
Automatic for AspectRatio assures that figures like circles and squares will \
not be distorted.  On the other hand, setting AspectRatio to a number causes \
the height to width ratio of the graphic the have the specified value.\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Show", "[", 
        RowBox[{"circ", ",", 
          StyleBox[\(AspectRatio \[Rule] Automatic\),
            FontColor->RGBColor[0.808606, 0.265629, 0.187503]], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{\({\(-10\), 10}\), ",", 
                StyleBox[\({\(-5\), 5}\),
                  FontColor->RGBColor[0.8, 0.2, 0.2]]}], "}"}]}]}], "]"}], 
      ";"}]], "Input",
  GeneratedCell->False],

Cell["\<\
If you are making geometrical diagrams you will probably want to set \
AspectRatio to Automatic. If you are plotting an equation you will more often \
want to set AspectRatio to a number. If the range of y was 1000 times the \
range of x then it just wouldn't work to use Automatic. If the plot was one \
inch wide, it would be 1000 inches high!\
\>", "Text"],

Cell[TextData[{
  "In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " the default setting of AspectRatio is usually 1/GoldenRatio. The Golden \
Ratio was a number determined by the ancient Greeks to give the most pleasing \
proportion for a rectangle.  It is an interesting mathematical number in \
itself.  Here is a plot using the Golden Ratio."
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{\(x\^3\), ",", \({x, \(-5\), 5}\), ",", 
          StyleBox[\(AspectRatio \[Rule] 1/GoldenRatio\),
            FontColor->RGBColor[0.8, 0.2, 0.2]], 
          StyleBox[",",
            FontColor->RGBColor[0.8, 0.2, 0.2]], 
          StyleBox[\(PlotRange \[Rule] All\),
            FontColor->RGBColor[0.8, 0.2, 0.2]], 
          ",", \(Background \[Rule] RGBColor[0.982, 0.96, 0.93]\)}], 
        "\[IndentingNewLine]", "]"}], ";"}]], "Input",
  GeneratedCell->False],

Cell["\<\
It just wouldn't do to use AspectRatio\[Rule]Automatic for this plot. Try it \
and see what happens!\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{\(x\^3\), ",", \({x, \(-5\), 5}\), ",", 
          StyleBox[\(AspectRatio \[Rule] Automatic\),
            FontColor->RGBColor[0.8, 0.2, 0.2]], 
          StyleBox[",",
            FontColor->RGBColor[0.8, 0.2, 0.2]], 
          StyleBox[\(PlotRange \[Rule] All\),
            FontColor->RGBColor[0.8, 0.2, 0.2]], 
          ",", \(Background \[Rule] RGBColor[0.982, 0.96, 0.93]\)}], 
        "\[IndentingNewLine]", "]"}], ";"}]], "Input",
  GeneratedCell->False],

Cell["\<\
One should keep in mind that the ImplicitPlot (from the standard packages) \
uses  (AspectRatio\[Rule]Automatic)  by default. The default setting is often \
preferred since ImplicitPlot is often used to make Plots of circles and \
related functions.  However, in some situations this default setting will \
produce a useless graphic.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BoxRatios", "Section"],

Cell[TextData[{
  "Plot3D, SurfaceGraphics and any functions that return SurfaceGraphics have \
the BoxRatios option with the default setting ",
  StyleBox["{1,1,0.4}", "Input",
    FontWeight->"Plain",
    Background->None,
    FontVariations->{"CompatibilityType"->0}],
  ". When this default setting is used the length of the two horizontal axes \
is always equal, and the height of the vertical axis is 40% of either \
horizontal axis. Using this default setting in the next line one gets the \
impression that the function rapidly oscillates."
}], "Text"],

Cell[BoxData[
    \(\(Plot3D[Sin[x\ y]/3, {x, \(-3\), 3}, {y, 0, 6}, 
        PlotPoints -> 30];\)\)], "Input"],

Cell["\<\
Instead one can set BoxRatios to Automatic to ensure that the resulting \
graphic is not distorted in that each axis is displayed using the same scale. \
 When the previous line is evaluated with BoxRatios set to Automatic, the \
figure is relatively short in the vertical direction since the values of \
Sin[x y]/3 varies over [-1/3, 1/3] which is much less than the variation of  \
x, y values . You might find that the line below gives a more accurate \
impression of how rapidly the function oscillates. 
\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot3D", "[", 
        RowBox[{\(Sin[x\ y]/3\), ",", \({x, \(-3\), 3}\), ",", \({y, 0, 6}\), 
          ",", "\n", \(PlotPoints -> 30\), ",", 
          StyleBox[\(BoxRatios -> Automatic\),
            FontColor->RGBColor[0.8047, 0.265629, 0.187503]]}], "]"}], 
      ";"}]], "Input"],

Cell["\<\
Obviously setting BoxRatios to Automatic would be a very bad choice to plot \
(Sin[x y]/100) over the same plot range as in the last example.

Contrary to the way Plot3D works ParametricPlot3D sets BoxRatios to Automatic \
by default.  This default setting is used in the next example and produces a \
nice parametric plot of a 3D-spiral.
 \
\>", "Text"],

Cell[BoxData[
    \(\(ParametricPlot3D[{Cos[2\ t], Sin[2\ t], 10/t}, \n\t{t, 2, 12}, 
        Axes -> False, ImageSize -> {200, 300}];\)\)], "Input"],

Cell["\<\
Now in the next line the default setting for BoxRatios produces a graph \
that's very tall and thin
 \
\>", "Text"],

Cell[BoxData[
    \(\(ParametricPlot3D[{Cos[2\ t], Sin[2\ t], 30/t}, \n\t{t, 0.05, 2}, 
        Axes -> False, ImageSize -> {200, 300}];\)\)], "Input"],

Cell[TextData[{
  "A better presentation of the last graphic is made by setting BoxRatios to \
",
  StyleBox["{1,1,0.4}", "Input",
    FontWeight->"Plain",
    Background->None,
    FontVariations->{"CompatibilityType"->0}],
  " in the next line. \n "
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{\({Cos[2\ t], Sin[2\ t], 30/t}\), ",", "\n", 
          "\t", \({t, 0.05, 2}\), ",", \(Axes -> False\), 
          ",", \(ImageSize -> {200, 300}\), ",", 
          StyleBox[\(BoxRatios \[Rule] {1, 1, 1.5}\),
            FontColor->RGBColor[0.8047, 0.265629, 0.187503]]}], "]"}], 
      ";"}]], "Input"],

Cell["\<\
Graphics3D also set BoxRatios to Automatic by default.  In addition the \
following functions in the standard packages set BoxRatios to Automatic by \
default; 
   ListPlotVectorField3D
   PlotVectorField3D
   PlotGradientField3D
   SphericalPlot3D
   CylindricalPlot3D
   PointParametricPlot3D
   ListSurfacePlot3D
   ScatterPlot3D
   ContourPlot3D
   ListContourPlot3D
 
I know of no other functions with the default setting  \
(BoxRatios\[Rule]Automatic).\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Circle, Disk", "Section"],

Cell["The basic use of Circle is demonstrated with the next cell.", "Text"],

Cell[BoxData[{
    \(\(crv = Plot[x^3, {x, 0, 3}, DisplayFunction -> Identity];\)\), "\n", 
    \(\(cir1 = 
        Graphics[{Circle[{1.25, 12.5}, {0.25, 2.5}]\ \ \ }];\)\), "\n", 
    \(\(Show[crv, cir1, DisplayFunction -> $DisplayFunction, \n
        PlotRange \[Rule] {\(-2\), 30}];\)\)}], "Input"],

Cell[TextData[{
  "The next cell demonstrates a circle with radi specified using ",
  ButtonBox["scaled",
    ButtonData:>"Scaled",
    ButtonStyle->"Hyperlink"],
  " coordinates.  In this case the radius is 1/4 the width of the graphic in \
the horizontal direction and 1/4 of the height of the graphic in the vertical \
direction.  Hence the diameter is 1/2 the size of the graphic in each \
direction."
}], "Text"],

Cell[BoxData[{
    \(\(cir2 = 
        Graphics[{Circle[{1.25, 12.5}, 
              Scaled[{0.25, 0.25}]]\ \ \ }];\)\), "\n", 
    \(\(Show[crv, cir2, DisplayFunction -> $DisplayFunction, \n
        PlotRange \[Rule] {\(-2\), 30}];\)\)}], "Input"],

Cell[TextData[{
  "The next cell makes a circle with radi given as a combination of ",
  ButtonBox["scaled",
    ButtonData:>"Scaled",
    ButtonStyle->"Hyperlink"],
  " coordinates and absolute coordinates."
}], "Text"],

Cell[BoxData[{
    \(\(cir3 = 
        Graphics[{Circle[{1.5, 10}, 
              Scaled[{0.1, 0.125}, {0.7, 6}]]\ \ \ }];\)\), "\n", 
    \(\(Show[crv, cir3, DisplayFunction -> $DisplayFunction, \n
        PlotRange \[Rule] {\(-2\), 30}];\)\)}], "Input"],

Cell[TextData[{
  "The documentation for Circle indicates ",
  ButtonBox["Offset[{ax,ay}]",
    ButtonData:>"Offset",
    ButtonStyle->"Hyperlink"],
  " can be used to specify radii in printer points.  This is demonstrated \
below where the circle is round with a radius of 15 printer points regardless \
of the AspectRatio or ImageSize.  You can even resize the graphic, and the \
size of the circle will not change!\n \n",
  Cell[BoxData[
      \(Offset\ [{a\_x, a\_y}]\)],
    FontFamily->"Times New Roman"],
  " can also be used to specify radius of a Disk with similar results.\n "
}], "Text"],

Cell[BoxData[{
    \(\(crv = Plot[x^3, {x, 0, 3}, DisplayFunction -> Identity];\)\), "\n", 
    \(\(cir = 
        Graphics[{Circle[{1.5, 10}, Offset[{15, 15}]]\ \ }];\)\n\ \), "\n", 
    \(\(Show[crv, cir, DisplayFunction -> $DisplayFunction, \n
        AspectRatio -> 1, ImageSize -> {180, 180}];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ColorFunction", "Section"],

Cell["\<\
Most graphics functions in Mathematica have a ColorFunction option.  The \
value of a function is used to specify the color or shade of gray used to \
make each portion of the graphic.  Some examples of ColorFunction are shown \
below. The \"#&\" notation is explained in my discussion of Slot, \
SlotSequence. \
\>", "Text",
  CellTags->"ColorFunction"],

Cell[BoxData[
    \(\(Plot3D[
        Sin[x + y], {x, \(-\[Pi]\), \[Pi]}, {y, \(-\[Pi]\), \[Pi]}, \n\t
        ColorFunction -> \((If[# < 1/2, GrayLevel[0.5], 
                GrayLevel[0.8]] &)\)];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot3D[
        Sin[x + y], {x, \(-\[Pi]\), \[Pi]}, {y, \(-\[Pi]\), \[Pi]}, \n\t
        ColorFunction -> \((RGBColor[0.1 + 0.8  #, 0, 0.9 - 0.8  #] &)\), \n
        Mesh -> False, PlotPoints -> 30];\)\)], "Input"],

Cell["\<\
You will find we can't have a ColorFunction that is sometimes a color and \
sometimes a GrayLevel.  However, we can still get the same result by using \
RGBColor[a,a,a]  in place of GrayLevel[a] as in the next cell.    \
\>", "Text"],

Cell[BoxData[
    \(\(Plot3D[
        Sin[x + y], {x, \(-\[Pi]\), \[Pi]}, {y, \(-\[Pi]\), \[Pi]}, \n\t
        ColorFunction -> \((If[# < 1/2, Hue[0.4], 
                RGBColor[0.8, 0.8, 0.8]] &)\)];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ColorFunctionScaling", "Section"],

Cell[TextData[{
  "ColorFunctionScaling is an option for SurfaceGraphics, DensityGraphics, \
ContourGraphics, Raster and functions that return these graphic objects.  The \
default setting is (ColorFunctionScaling\[Rule]True) in which case function \
values are scaled such that the minimum value is mapped to 0 and the maximum \
value is mapped to 1.  These mapped values are then used to determine a color \
for each point on the plot.  The color is determined from the setting of the \
",
  ButtonBox["ColorFunction",
    ButtonData:>"ColorFunction",
    ButtonStyle->"Hyperlink"],
  " option. When the setting (ColorFunctionScaling\[Rule]False) is used the \
function values are sent directly to the function determined by the \
ColorFunction setting. Notice when the setting \
(ColorFunction\[Rule]Automatic) is used a negative value has the same effect \
as 0 and a value greater than 1 has the same effect as 1. \nThe cells that \
follow demonstrate how ColorFunctionScaling affects DensityGraphics and \
ContourGraphics."
}], "Text",
  CellTags->"ColorFunctionScaling"],

Cell[BoxData[{
    \(\(DensityPlot[Cos[x\ y]/10 + 1/2, {x, \(-3\), 3}, {y, \(-3\), 3}, 
        ColorFunctionScaling \[Rule] True];\)\), "\n", 
    \(\(DensityPlot[Cos[x\ y]/10 + 1/2, {x, \(-3\), 3}, {y, \(-3\), 3}, 
        ColorFunctionScaling -> False];\)\)}], "Input"],

Cell[BoxData[{
    \(\(ContourPlot[Cos[x\ y]/10 + 1/2, {x, \(-3\), 3}, {y, \(-3\), 3}, 
        ColorFunctionScaling \[Rule] True];\)\), "\n", 
    \(\(ContourPlot[Cos[x\ y]/10 + 1/2, {x, \(-3\), 3}, {y, \(-3\), 3}, 
        ColorFunctionScaling -> False];\)\)}], "Input"],

Cell["\<\
ColorFunctionScaling is a SurfaceGraphics option and only affects rendering \
of SurfaceGraphics when the setting (Lighting\[Rule]False) is used. Plot3D \
returns SurfaceGraphics and the next cell demonstrates the use of \
ColorFunctionScaling with Plot3D.\
\>", "Text"],

Cell[BoxData[{
    \(\(\(Plot3D[
        Cos[x\ y]/10 + 1/2, {x, \(-3\), 3}, {y, \(-3\), 
          3}, \[IndentingNewLine]ColorFunctionScaling \[Rule] True, 
        Lighting \[Rule] False];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Plot3D[
        Cos[x\ y]/10 + 1/2, {x, \(-3\), 3}, {y, \(-3\), 
          3}, \[IndentingNewLine]ColorFunctionScaling \[Rule] False, 
        Lighting \[Rule] False];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ColorOutput", "Section"],

Cell[BoxData[
    \(\(?ColorOutput\)\)], "Input"],

Cell["\<\
According to technical support at  Wolfram Research ColorOutput is primarily \
intended for those situations when you are exportiing Mathematica graphics to \
Adobe post script or EPS.  They say it allows some additional control over \
how the color output is handled in these circumstances, but I haven't come up \
with an example.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DisplayFunction", "Section"],

Cell["\<\
DisplayFunction is an option for most graphics functions, and is normally \
used to indicate whether the graphics should be displayed.  As long as you \
haven't changed the value assigned to $DisplayFunction you can ensure \
graphics are displayed by giving DisplayFunction the setting \
$DisplayFunction.  To prevent the display of graphics DisplayFunction should \
be set to Identity.

For example the next cell shows a plot sin[x], x-(x^3)/6 on the same graphic, \
but before making the combined plot it makes and displays the individual \
plots.\
\>", "Text"],

Cell[BoxData[{
    \(\(plt1 = Plot[Sin[x], {x, \(-\[Pi]\), \[Pi]}];\)\), "\n", 
    \(\(plt2 = Plot[x - x\^3\/6, {x, \(-2\), 2}];\)\), "\n", 
    \(\(Show[plt1, plt2];\)\)}], "Input"],

Cell[TextData[{
  "You can supress display of the individual plots by using the \
DisplaFunction options in the next cell.  Here ",
  Cell[BoxData[
      \(TraditionalForm\`DisplayFunction \[Rule] Identity\)]],
  " prevents display of the individual graphs.  To ensure the combined plots \
are displayed we must use ",
  Cell[BoxData[
      \(TraditionalForm\`DisplayFunction \[Rule] $DisplayFunction\)]],
  " inside Show."
}], "Text"],

Cell[BoxData[{
    \(\(plt1 = 
        Plot[Sin[x], {x, \(-\[Pi]\), \[Pi]}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(plt2 = 
        Plot[x - x\^3\/6, {x, \(-2\), 2}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(Show[plt1, plt2, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input"],

Cell["\<\
A labor saving way to change the setting of DisplayFunction is given in my \
discussion of Block.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["EdgeForm", "Section"],

Cell["The next cell displays the usage message for EdgeForm.", "Text",
  CellTags->"EdgeForm"],

Cell[BoxData[
    \(\(?EdgeForm\)\)], "Input"],

Cell["\<\
The usage message for EdgeForm indicates  EdgeForm is a \"three-dimensional \
graphics directive\" this indicates it can be used inside Graphics3D and with \
functions that produce Graphics3D expressions.  ParametricPlot3D produces \
Graphics3D, and it's usage message indicates that \
ParametricPlot3D[{fx,fy,fz,s},{x,xmin,xmax},{ymin,ymax}] produces a plot \
shaded according to the color specification (s).  Here (s) can be a single \
three-dimensional graphics directive or a list of three-dimensional graphics \
directives.

Consider the next cell where the default EdgeForm around polygons is used.\
\>", "Text",
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 0}],

Cell[BoxData[
    \(\(ParametricPlot3D[{x, y, Sin[x\ y/3]}, {x, 0, 3}, {y, 0, 
          3}];\)\)], "Input"],

Cell["\<\
The next cell makes the same graphic except no edges are drawn around the \
polygons.\
\>", "Text"],

Cell[BoxData[
    \(\(ParametricPlot3D[{x, y, Sin[x\ y/3], EdgeForm[]}, {x, 0, 3}, {y, 0, 
          3}];\)\)], "Input"],

Cell["\<\
The next cell plots the same function using a gray edges around the polygons.\
\
\>", "Text"],

Cell[BoxData[
    \(\(ParametricPlot3D[{x, y, Sin[x\ y/3], EdgeForm[GrayLevel[0.5]]}, {x, 
          0, 3}, {y, 0, 3}];\)\)], "Input"],

Cell["\<\
The next cell uses colored edges where the color varies as a function of x \
and y.\
\>", "Text"],

Cell[BoxData[
    \(\(ParametricPlot3D[{x, y, Sin[x\ y/3], 
          EdgeForm[RGBColor[1 - x/3, 1 - y/3, 0]]}, \[IndentingNewLine]{x, 0, 
          3}, {y, 0, 3}];\)\)], "Input"],

Cell["\<\
The next cell uses thick colored edges where the color varies as a function \
of x and y.\
\>", "Text"],

Cell[BoxData[
    \(\(ParametricPlot3D[{x, y, 
          Sin[x\ y/3], \[IndentingNewLine]EdgeForm[{RGBColor[1 - x/3, 
                1 - y/3, 0], 
              AbsoluteThickness[4]}]\ }, \[IndentingNewLine]\ {x, 0, 3}, {y, 
          0, 3}, PlotPoints -> 8\[IndentingNewLine]];\)\)], "Input"],

Cell["\<\
An example is given below where EdgeForm is used with Grapgics3D.  Here \
EdgeForm[] indicates no edges should be drawn around the polygons.\
\>", "Text"],

Cell[BoxData[{
    \(Needs["\<Graphics`Shapes`\>"]\), "\n", 
    \(\(Show[Graphics3D[{EdgeForm[], Torus[]}]];\)\)}], "Input"],

Cell["In the next cell Gray edges around the polygons are used.", "Text"],

Cell[BoxData[
    \(\(Show[
        Graphics3D[{EdgeForm[Thickness[0.01], GrayLevel[0.5]], 
            Torus[]}]];\)\)], "Input"],

Cell[TextData[{
  "Keep in mind that DensityPlot, ListDensityPlot, ListPlot3D, Plot and \
Plot3D don't produce Graphics3D expressions.  Instead one should use the \
options ",
  ButtonBox["Mesh and MeshStyle",
    ButtonData:>"Mesh",
    ButtonStyle->"Hyperlink"],
  " to get similar results with DensityPlot, ListDensityPlot, ListPlot3D, \
Plot and Plot3D. "
}], "Text",
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 0}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Epilog, Prolog", "Section"],

Cell["\<\
Epilog and Prolog are options for Graphics functions which give are used to \
give a list of graphics primative (Circle, Line, Point, ...) to be rendered \
before or after the main part of the graph.  The Prolog  graphics are \
rendered before the main part of the graphics.  The Epilog graphics are \
rendered after the main part of the graphics.

The cell below shows red points drawn before the line using Prolog.  Also \
shown are red points drawn after the lines using Epilog.
 \
\>", "Text"],

Cell[BoxData[{
    \(\(\(data1 = Table[{x, x}, {x, 0, 6}];\)\(\n\)
    \)\), "\n", 
    \(\(\(Block[{$DisplayFunction = Identity}, \n\t\n
      PointsFirst = 
        ListPlot[data1, 
          PlotJoined -> 
            True, \n\t\tPlotStyle -> {GrayLevel[0], 
              Thickness[0.02]}, \n\t\tProlog -> {Hue[1], PointSize[0.1], 
              Point /@ data1}, \n\ \ \ \ \ \ PlotRange -> {{\(-0.5\), 
                6}, {\(-0.5\), 6}}]; \n\t\n
      PointsLast = 
        ListPlot[data1, 
          PlotJoined -> 
            True, \n\t\tPlotStyle -> {GrayLevel[0], 
              Thickness[0.02]}, \n\t\tEpilog -> {Hue[1], PointSize[0.1], 
              Point /@ data1}, \n\ \ \ \ \ \ PlotRange -> {{\(-0.5\), 
                6}, {\(-0.5\), 6}}];\n]\)\(\n\)
    \)\), "\n", 
    \(\(Show[GraphicsArray[{PointsFirst, PointsLast}], 
        ImageSize -> {400, 100}];\)\)}], "Input"],

Cell["\<\
The next example was inspired by a problem Jurgen Tisher answered in the \
MathGroup.  You should be wary of using  Epilog and Prolog for applications \
where you may combine the results with other graphics at a later time using \
Show.  The reason for this is demonstrated in this example.
 \
\>", "Text"],

Cell[BoxData[{
    \(\(data1 = Table[{x, x}, {x, 0, 6}];\)\), "\n", 
    \(\(\(data2 = Table[{x, x + 2}, {x, 0, 6}];\)\(\n\)
    \)\), "\n", 
    \(\(\(Block[{$DisplayFunction = Identity}, \n\t\n
      p1 = ListPlot[data1, 
          PlotJoined -> 
            True, \n\t\tEpilog -> {Hue[1], \n\t\t\t\t\tPointSize[0.06], 
              Point /@ data1}, \n\ \ \ \ \ \ PlotRange -> {{\(-0.5\), 
                6.5}, {\(-0.5\), 8.5}}]; \n\t\n
      p2 = ListPlot[data2, 
          PlotJoined -> 
            True, \n\t\tEpilog -> {Hue[1], \n\t\t\t\t\tPointSize[0.06], 
              Point /@ data2}, \n\ \ \ \ \ \ PlotRange -> {{\(-0.5\), 
                6.5}, {\(-0.5\), 8.5}}];\n]\)\(\n\)
    \)\), "\n", 
    \(\(Show[GraphicsArray[{p1, p2}], ImageSize -> {400, 100}];\)\)}], "Input"],

Cell["\<\
In the GraphicsArray above the Points made with Epilog are shown in the plots \
for p1 and p2.  When the two graphics below are combined only the Epilog \
graphics for p1 are shown.\
\>", "Text"],

Cell[BoxData[
    \(\(Show[p1, p2];\)\)], "Input"],

Cell["\<\
The Epilog graphics for p2 were not displayed because Show concatenates \
together the options for each graphic.  As a result only the first Epilog \
options and the first Prolog option is used.  By using FullGraphics the \
graphics for p1 and p2 can be converted to graphic primitives, and all the \
intended graphics are displayed.  However, this demonstration is misleading \
because the manual settings used for PlotRange above were carefully selected \
to ensure the result below comes out looking good.  If you make p1 and p2 \
using the PlotRange\[Rule]Automatic the graphic below doesn't come out as \
nice.  

It turns out that Prolog has the same weakness.
 \
\>", "Text"],

Cell[BoxData[
    \(\(Show[FullGraphics[p1], FullGraphics[p2]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FrameTicks", "Section"],

Cell[CellGroupData[{

Cell["\<\
A user wanted to present data on the y axis and refer to it with 2 equivalent \
scales 
(degrees Fahrenheit and degrees Celcius)\
\>", "Subsubsection"],

Cell["\<\
Wolf Hartmut gave a solution where he demonstrates by first defining a fever \
curve (temp) in Centigrade units, and a Plot of the curve is assigned to \
graphC.\
\>", "Text"],

Cell[BoxData[{
    \(\(\(tempC = 
        Join[Table[Random[Real] + 37.25, {4}], 
          Table[6  x/E^x + Random[Real] + 37.25, {x, 0, 6, 0.2}]];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(graphC = 
        ListPlot[tempC, PlotJoined \[Rule] True, PlotRange \[Rule] All, 
          Frame \[Rule] True, Axes \[Rule] None, 
          FrameTicks \[Rule] {Automatic, Automatic, None, None}, 
          DisplayFunction \[Rule] Identity];\)\)}], "Input"],

Cell["\<\
Ticks2 are the original FrameTicks redefined so the text for Clesius degrees \
are placed at the equivalent place on a graph with Farenheight units.\
\>", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Miscellaneous`Units`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Ticks2 = \({ConvertTemperature[#1, Centigrade, Fahrenheit], 
              If[#2 \[Equal] "\<\>", #2, #1], #3, #4} &\) @@@ \(FullOptions[
              graphC, FrameTicks]\)[\([2]\)];\)\)}], "Input"],

Cell["\<\
Next the fever curve is converted to Fahrenheit, and  this is plotted with \
Ticks2.  The altered FrameTicks are used on the left edge of the graph.\
\>", "Text"],

Cell[BoxData[{
    \(\(\(tempF = \(ConvertTemperature[#, Centigrade, Fahrenheit] &\) /@ 
          tempC;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(ListPlot[tempF, PlotJoined \[Rule] True, PlotRange \[Rule] All, 
        Frame \[Rule] True, Axes \[Rule] None, 
        FrameTicks \[Rule] {Automatic, Automatic, None, Ticks2}, 
        FrameLabel \[Rule] {None, "\<Fahrenheit\>", 
            None, "\<Centigrade\>"}];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
A user wanted to have two graphs displayed one above the other in a \
GraphicsArray, and 
have the vertical axes alligned with eachother\
\>", "Subsubsection",
  CellFrame->{{0, 0}, {0, 0.5}}],

Cell["\<\
Bob Hanlon recommended using an identical but  \"invisible\" FrameTick on \
each graph's axis that is slightly wider than the widest actual tick label as \
below.\
\>", "Text"],

Cell[BoxData[{
    \(\(\(fig1 = 
        Plot[x, {x, 0, 10}, 
          Frame \[Rule] 
            True, \[IndentingNewLine]FrameTicks \[Rule] {Automatic, \
\[IndentingNewLine]Join[\[IndentingNewLine]Table[{k, k}, {k, 0, 10, 2}], 
                Table[{k, "\<    \>"}, {k, 0, 10, 1}]\[IndentingNewLine]], 
              Automatic, Automatic\[IndentingNewLine]}, 
          DisplayFunction \[Rule] 
            Identity\[IndentingNewLine]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(fig2 = 
        Plot[x^4, {x, 0, 10}, Frame \[Rule] True, 
          FrameTicks \[Rule] {Automatic, \[IndentingNewLine]Join[\
\[IndentingNewLine]Table[{k, k}, {k, 0, 2000, 500}], 
                Table[{k, "\<    \>"}, {k, 0, 2100, 
                    100}]\[IndentingNewLine]], Automatic, 
              Automatic\[IndentingNewLine]}, 
          DisplayFunction \[Rule] 
            Identity\[IndentingNewLine]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{{fig1}, {fig2}}], 
        ImageSize \[Rule] {300, 388}];\)\)}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["HiddenSurface", "Section"],

Cell[TextData[{
  "HiddenSurface is an option for SurfaceGraphics, Plot3D and other funtions \
that return SurfaceGraphics.  The default setting is \
(HiddenSurface\[Rule]True) which causes the surface to be drawn using \
simulated lighting as long as the setting (Lighting\[Rule]True) is used.  The \
setting (HiddenSurface\[Rule]False) draws the surface as a transparent wire \
mesh.  Evaluating the next cell demonstrates both HiddenSurface settings. The \
",
  ButtonBox["Shading",
    ButtonData:>"Shading",
    ButtonStyle->"Hyperlink"],
  " option is used to render the surface as a mesh of opaque mesh of \
polygons."
}], "Text",
  CellTags->"HiddenSurface"],

Cell[BoxData[
    \(Plot3D[Exp[\(-\((x\^4 + y\^4)\)\)], {x, \(-2\), 2}, {y, \(-2\), 2}, 
      HiddenSurface \[Rule] True]; 
    Plot3D[Exp[\(-\((x\^4 + y\^4)\)\)], {x, \(-2\), 2}, {y, \(-2\), 2}, 
      HiddenSurface \[Rule] False];\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ImplicitPlot", "Section"],

Cell["\<\
Either form of ImplicitPlot will take the options FormatType, ImageSize, \
TextStyle even though they aren't returned by Options[ImplicitPlot].  \
ImplicitPlot also takes the options ColorFunction, Compiled, ContourLines, \
ContourShading and ContourStyle but only when the ContourPlot method is used. \
 Each of these options except Compiled is demonstrated below.\
\>", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`ImplicitPlot`\>"];\)\), "\[IndentingNewLine]", 
    \(\(ImplicitPlot[x^2 + y^2 == 1/2, {x, 0, 0.75}, {y, 0, 0.75}, \ \n
        ColorFunction -> \((If[# < 0.5, \ GrayLevel[0.7], \ 
                GrayLevel[1]] &)\), \ ImageSize -> {200, 200}, \ 
        ContourLines -> False, \nContourShading -> True];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`ImplicitPlot`\>"];\)\), "\[IndentingNewLine]", 
    \(\(ImplicitPlot[
        ArcSin[x] - y == 0, {x, \(-1\), 1}, {y, \(-\[Pi]\)/2, \[Pi]/2}, \n
        PlotLabel -> HoldForm[ArcSin[x] = y], 
        ContourStyle -> Dashing[{0.02, 0.02}], \ \n\t
        TextStyle -> {FontColor -> Hue[0.7]}, 
        FormatType -> TraditionalForm];\)\)}], "Input"],

Cell["\<\
The documentation indicates ImplicitPlot uses one of two methods.  In the two \
cells above the ContourPlot method was used since a range of values for x and \
y were specified.  When the ContourPlot method is used the ContourStyle \
option is used to make the curve dotted.  In the next line the Solve method \
is used since no range is given for the range of (y) values.  Since the Solve \
method is used the PlotStyle option has to be used to make the curve dotted.  \
Whether you use PlotStyle or ContourStyle depends on the ImplicitPlot method \
being used (ContourPlot method, or Solve method).\
\>", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`ImplicitPlot`\>"];\)\), "\[IndentingNewLine]", 
    \(\(ImplicitPlot[ArcSin[x] - y == 0, {x, \(-1\), 1}, \n\ 
        PlotStyle -> Dashing[{0.02, 0.02}]\ ];\)\)}], "Input"],

Cell["\<\
Also note the documentation indicates ImplicitPlot uses the same options as \
plot when the solve method is used.  Actually MaxBend and PlotDivision are \
plot options, but they aren't recognized by either method of ImplicitPlot.\
\>", "Text"],

Cell["\<\
One should keep in mind that ImplicitPlot uses (AspectRatio\[Rule]Automatic) \
by default.  This ensures that the plot of a circle (below) looks like a \
circle.\
\>", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`ImplicitPlot`\>"];\)\), "\[IndentingNewLine]", 
    \(\(ImplicitPlot[x^2 + y^2 == 9, {x, \(-3\), 3}];\)\)}], "Input"],

Cell["\<\
However the default option (AspectRatio\[Rule]Automatic) causes a problem in \
the next cell.  In this case the range of values on the vertical axis is much \
larger than the range of values on the horizontal axis.  In this case the \
default setting for AspectRatio produces a useless graphic.  \
\>", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`ImplicitPlot`\>"];\)\), "\[IndentingNewLine]", 
    \(\(ImplicitPlot[y + x == Tan[x], {x, 0.8, 1.56}];\)\)}], "Input"],

Cell["\<\
Instead the AspectRatio used by most other plot commands \
(AspectRatio\[Rule]1/GoldenRatio) produces a much more useful graphic in the \
next line.  \
\>", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`ImplicitPlot`\>"];\)\), "\[IndentingNewLine]", 
    \(\(ImplicitPlot[y + x == Tan[x], {x, 0.8, 1.56}, 
        AspectRatio -> 1/GoldenRatio];\)\)}], "Input"],

Cell["\<\
In the following line Implicit Plot uses the default options and the curves \
aren't smooth.  To make the graphs smooth a value for the PlotPoints option \
has to be specified.  The default setting is PlotPoints->25.  The setting \
used in the second attempt work better.\
\>", "Text"],

Cell[BoxData[
    \(\(ImplicitPlot[
        Sin[2\ x]\  + \ Cos[3\ y]\  == \ 1, {x, \(-8\), 8}, {y, \(-8\), 
          8}];\)\)], "Input"],

Cell[BoxData[
    \(\(ImplicitPlot[
        Sin[2\ x]\  + \ Cos[3\ y]\  == \ 1, {x, \(-8\), 8}, {y, \(-8\), 8}, \n
        PlotPoints \[Rule] 200];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mesh, MeshStyle", "Section"],

Cell["\<\
By default Plot3D, ListPlot3D, DensityPlot and ListDensityPlot3D make a black \
mesh over the graphic.  In the next cell the setting (Mesh\[Rule]False) is \
used to supporess this grid.\
\>", "Text",
  CellTags->"Mesh"],

Cell[BoxData[{
    \(\(Plot3D[Sin[x + y], {x, \(-\[Pi]\), \[Pi]}, {y, 0, \[Pi]}, 
        Mesh \[Rule] False];\)\), "\[IndentingNewLine]", 
    \(\(DensityPlot[Sin[x + y], {x, \(-\[Pi]\), \[Pi]}, {y, 0, \[Pi]}, 
        Mesh \[Rule] False];\)\)}], "Input"],

Cell["\<\
In the next cell the MeshStyle option is used to make a green mesh.  Using \
this option one can specify the color and/or thickness of the grid.  You \
could also make a mesh of dashed lines if you wanted to.\
\>", "Text"],

Cell[BoxData[{
    \(\(Plot3D[Sin[x + y], {x, \(-\[Pi]\), \[Pi]}, {y, 0, \[Pi]}, 
        MeshStyle \[Rule] {Hue[0.3, 1, 0.7]}];\)\), "\[IndentingNewLine]", 
    \(\(DensityPlot[Sin[x + y], {x, \(-\[Pi]\), \[Pi]}, {y, 0, \[Pi]}, 
        MeshStyle \[Rule] {Hue[0.3, 1, 0.7]}];\)\)}], "Input"],

Cell[TextData[{
  "ParametricPlot3D requires use of ",
  ButtonBox["EdgeForm",
    ButtonData:>"EdgeForm",
    ButtonStyle->"Hyperlink"],
  " to do the same thing as Mesh and MeshStyle.  EdgeForm is also used with \
Graphics3D primitives rather than Mesh, MeshStyle."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MeshRange", "Section"],

Cell["\<\
MeshRange is an option for ListPlot3D, ListDensityPlot, ListContourPlot, \
SurfaceGraphics, DensityGraphics, and ContourGraphics. ListPlot3D, \
ListDensityPlot, and ListContourPlot are used to plot a matrix of numeric \
values.  When the default setting (MeshRange\[Rule]Automatic) is used these \
functions simply label the resulting tick marks as if the rows and columns of \
the matrix are numbered 1, 2, 3, ... This is what you get from evaluating the \
next cell.  These functions can't do any better because there is nothing in \
the data indicating otherwise.\
\>", "Text",
  CellTags->"MeshRange"],

Cell[BoxData[{
    \(\(data = 
        Table[\((x - 35)\)\^2\ \((y - 70)\)\^2/100, {x, 30, 40, 0.5}, {y, 60, 
            80, 1}];\)\), "\n", 
    \(\(ListPlot3D[data, MeshRange \[Rule] Automatic];\)\), "\n", 
    \(\(ListDensityPlot[data, MeshRange \[Rule] Automatic];\)\), "\n", 
    \(\(ListContourPlot[data, MeshRange \[Rule] Automatic];\)\)}], "Input"],

Cell["\<\
However, in the case above we know that the rows of data correspond to x \
values between 30 and 40. Likewise the columns of data correspond to y values \
between 60 and 80.  In the next cell the MeshRange option is used to ensure \
the TickMarks are relavent for this data.\
\>", "Text"],

Cell[BoxData[{
    \(\(ListPlot3D[data, MeshRange \[Rule] {{30, 40}, {60, 80}}];\)\), "\n", 
    \(\(ListDensityPlot[data, 
        MeshRange \[Rule] {{30, 40}, {60, 80}}];\)\), "\n", 
    \(\(ListContourPlot[data, 
        MeshRange \[Rule] {{30, 40}, {60, 80}}];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Offset, Scaled", "Section"],

Cell[BoxData[
    \(\(?Offset\)\)], "Input"],

Cell[TextData[{
  "In the next cell pnt1 is a red point at ",
  StyleBox["{1,0.025}", "Input",
    FontWeight->"Plain",
    Background->None,
    FontVariations->{"CompatibilityType"->0}],
  ".  The graphic made also shows pnt2, a blue point 20 printer points to the \
right and 10 printer points above ",
  StyleBox["{1,0.025}", "Input",
    FontWeight->"Plain",
    Background->None,
    FontVariations->{"CompatibilityType"->0}],
  ".  Notice distances in printer points aren't related to the scale on the \
axes."
}], "Text",
  CellTags->"Offset"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"pnt1", "=", 
          RowBox[{"Graphics", "[", 
            RowBox[{"{", 
              
              RowBox[{\(PointSize[0.03]\), ",", \(RGBColor[0.9, 0, 0]\), ",", 
                "\[IndentingNewLine]", 
                RowBox[{"Point", "[", 
                  StyleBox[\({1, 0.025}\),
                    FontColor->RGBColor[0.8, 0.2, 0.2]], "]"}]}], 
              "\[IndentingNewLine]", "}"}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"pnt2", "=", 
          RowBox[{"Graphics", "[", 
            RowBox[{"{", 
              
              RowBox[{\(PointSize[0.03]\), ",", \(RGBColor[0, 0, 0.9]\), ",", 
                "\[IndentingNewLine]", 
                RowBox[{"Point", "[", 
                  StyleBox[\(Offset[{20, 10}, {1, 0.025}]\),
                    FontColor->RGBColor[0.8, 0.2, 0.2]], "]"}]}], 
              "\[IndentingNewLine]", "}"}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", \(Show[{pnt1, pnt2}, 
        PlotRange \[Rule] {{\(-5\), 5}, {\(-0.1\), 0.1}}, 
        Axes -> True];\)}], "Input"],

Cell["The remaining examples used Offset and Scaled.", "Text",
  CellTags->"Scaled"],

Cell[BoxData[
    \(\(?Scaled\)\)], "Input"],

Cell["\<\
In the next cell pnt1 is a red point positioned such that the distance from \
the left edge of the graphic is 10% of the graphic width, and and the \
distance from the bottom of the graphic is 5% of the graphic height. Also \
shown is pnt2, a blue point 20 printer points to the right and 10 printer \
points above pnt1.\
\>", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"pnt1", "=", 
        RowBox[{"Graphics", "[", 
          RowBox[{"{", 
            
            RowBox[{\(PointSize[0.03]\), ",", \(RGBColor[0.9, 0, 0]\), ",", 
              "\[IndentingNewLine]", 
              RowBox[{"Point", "[", 
                StyleBox[\(Scaled[{0.1, 0.05}]\),
                  FontColor->RGBColor[0.8, 0.2, 0.2]], "]"}]}], 
            "\[IndentingNewLine]", "}"}], "]"}]}], ";"}], "\n", 
    RowBox[{
      RowBox[{"pnt2", "=", 
        RowBox[{"Graphics", "[", 
          RowBox[{"{", 
            
            RowBox[{\(PointSize[0.03]\), ",", \(RGBColor[0, 0, 0.9]\), ",", 
              "\[IndentingNewLine]", 
              RowBox[{"Point", "[", 
                StyleBox[\(Offset[{20, 10}, Scaled[{0.1, 0.05}]]\),
                  FontColor->RGBColor[0.8, 0.2, 0.2]], "]"}]}], 
            "\[IndentingNewLine]", "}"}], "]"}]}], 
      ";"}], "\n", \(Show[{pnt1, pnt2}, 
        PlotRange \[Rule] {{\(-5\), 5}, {\(-0.1\), 0.1}}, 
        Axes -> True];\)}], "Input"],

Cell[TextData[{
  "In the next cell pnt1 is a red point at ",
  StyleBox["{1,0.025}", "Input",
    FontWeight->"Plain",
    Background->None,
    FontVariations->{"CompatibilityType"->0}],
  ".  Also shown is pnt2, a blue point at the position ",
  Cell[BoxData[
      \(TraditionalForm\`Scaled[{0.1, 0.05}, {1, 0.025}]\)]],
  " which is to the right of pnt1 by 10% of the graphic width, and above pnt1 \
by 5% of the graphic height.  In addition pnt3 is shown which is a green \
point 10 printer points to the right of pnt2, and 20 printer points higher \
than pnt2."
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"pnt1", "=", 
        RowBox[{"Graphics", "[", 
          RowBox[{"{", 
            
            RowBox[{\(PointSize[0.03]\), ",", \(RGBColor[0.9, 0, 0]\), ",", 
              "\[IndentingNewLine]", 
              RowBox[{"Point", "[", 
                StyleBox[\({1, 0.025}\),
                  FontColor->RGBColor[0.8, 0.2, 0.2]], "]"}]}], 
            "\[IndentingNewLine]", "}"}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"pnt2", "=", 
        RowBox[{"Graphics", "[", 
          RowBox[{"{", 
            
            RowBox[{\(PointSize[0.03]\), ",", \(RGBColor[0, 0, 0.9]\), ",", 
              "\[IndentingNewLine]", 
              RowBox[{"Point", "[", 
                StyleBox[\(Scaled[{0.1, 0.05}, {1, 0.025}]\),
                  FontColor->RGBColor[0.8, 0.2, 0.2]], "]"}]}], 
            "\[IndentingNewLine]", "}"}], "]"}]}], ";"}], "\n", 
    RowBox[{
      RowBox[{"pnt3", "=", 
        RowBox[{"Graphics", "[", 
          RowBox[{"{", 
            
            RowBox[{\(PointSize[0.03]\), ",", \(RGBColor[0, 0.9, 0]\), ",", 
              "\[IndentingNewLine]", 
              RowBox[{"Point", "[", 
                
                StyleBox[\(Offset[{10, 20}, 
                    Scaled[{0.1, 0.05}, {1, 0.025}]]\),
                  FontColor->RGBColor[0.8, 0.2, 0.2]], "]"}]}], 
            "\[IndentingNewLine]", "}"}], "]"}]}], 
      ";"}], "\n", \(Show[{pnt1, pnt2, pnt3}, 
        PlotRange \[Rule] {{\(-5\), 5}, {\(-0.1\), 0.1}}, 
        Axes -> True];\)}], "Input"],

Cell["\<\
A practical use of Offset is given in the next cell where it's used to \
specify the position of some text.\
\>", "Text"],

Cell[BoxData[{
    RowBox[{\(plt = 
          Plot[BesselJ[2, x], {x, 0, 8}, DisplayFunction \[Rule] Identity, 
            PlotRange \[Rule] {\(-0.4\), 0.6}];\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\(pnt = 
          Graphics[\[IndentingNewLine]{PointSize[0.02], 
              Point[{3.05424, BesselJ[2, 3.05424]}]}];\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"txt", "=", 
        RowBox[{"Graphics", "[", 
          RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{"Text", "[", 
              RowBox[{"\"\<Local Maxima\>\"", ",", 
                StyleBox[\(Offset[{12, 0}, {3.05424, BesselJ[2, 3.05424]}]\),
                  FontColor->RGBColor[0.8, 0.2, 0.2]], 
                ",", \({\(-1\), \(-1\)}\)}], "]"}], "\[IndentingNewLine]", 
            "}"}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", \(Show[{plt, pnt, txt}, 
        DisplayFunction \[Rule] $DisplayFunction];\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PolygonIntersections", "Section"],

Cell["\<\
PolygonIntersections is an option for Graphics3D and funtions that return \
Graphics3D objects.\
\>", "Text",
  CellTags->"PolygonIntersections"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[Graphics3D, PolygonIntersections]\)], "Input"],

Cell[BoxData[
    \({PolygonIntersections \[Rule] True}\)], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell["\<\
When the setting  PolygonIntersections\[Rule]False  is used the graphics are \
rendered as a collection of non-intersecting triangles.  In the next cell I \
make a Graphics3D object with non-default setting \
(PolygonIntersections\[Rule]False).\
\>", "Text"],

Cell[BoxData[
    \(\(gr = 
        Graphics3D[{\[IndentingNewLine]Polygon[{{0, 0, 1}, {0, 1, 1}, {1, 1, 
                  1}, {1, 0, 1}\ }], \[IndentingNewLine]Polygon[{{0.5, 0, 
                  0}, {0.5, 1, 0}, {0.5, 1, 2}, {0.5, 0, 
                  2}}]\[IndentingNewLine]}, 
          PolygonIntersections \[Rule] False];\)\)], "Input"],

Cell["\<\
I can't inderstand why but my attempt to display the graphics in the next \
cell doesn't work when using Mathematica 4.1 under Windows 98.\
\>", "Text"],

Cell[BoxData[
    \(\(Show[gr, PlotRange -> All];\)\)], "Input"],

Cell["\<\
On my computer the above graphics can be displayed if I nest use of Show, and \
specify (PlotRange->All).\
\>", "Text"],

Cell[BoxData[
    \(\(Show[Show[gr], PlotRange -> All];\)\)], "Input"],

Cell["\<\
The next cell shows us how Mathematica divided the above polygons into \
non-intersecting triangles.\
\>", "Text"],

Cell[BoxData[
    \(polygons = Cases[Show[gr], _Polygon, {0, \(-1\)}] // Chop\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rectangle", "Section"],

Cell[TextData[{
  "Rectangle is a griphics primative. The Rectangle coordinates can be ",
  ButtonBox["Scaled, Offset",
    ButtonData:>"Offset",
    ButtonStyle->"Hyperlink"],
  ", or (Scaled and Offset) and these features are explained in another \
section.  Except for non-stnadard coordinates the basic use of Rectangle is \
well documented.  On the other hand  Rectangle has an interesting feature in \
that it can take a graphics object as a third argument, and I demonstrate \
this feature here.\n\nConsider the two plots made with the next cell."
}], "Text",
  CellTags->"Rectangle"],

Cell[BoxData[{
    \(\(\(gr1 = 
        Plot[\(Sin[x] Sin[5  x]\)\/x, {x, \(-14\), 14}, 
          PlotRange -> All];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(gr2 = 
        Plot[\(Sin[x] Sin[5  x]\)\/x, {x, 10, 14}, 
          PlotRange -> All];\)\)}], "Input"],

Cell["\<\
A nice presentation of these plots would have the graphic with a smaller plot \
range in the upper right corner used to display the one with a larger plot \
range.  We can do that by giving Rectangle these graphics as third arguments \
in the next cell.\
\>", "Text"],

Cell[BoxData[
    \(\(Show[
        Graphics[{\[IndentingNewLine]Rectangle[{0, 0}, {1.02, 1.02}, gr1], 
            Rectangle[{0.6, 0.7}, {1, 1}, gr2]}], PlotRange -> All, 
        ImageSize -> {500, 400}];\)\)], "Input"],

Cell["\<\
To explain what happens above consider the next cell which is similar to the \
previous cell.  The next cell makes a red rectangle and a blue in the upper \
left corner of the red rectangle (Hue[0] is red, and Hue[0.6] is blue). In \
the previous cell the first Rectangle had (gr1) as a third argument, and that \
makes the rectangle filled in with graphic (gr1)  instead of a solid color.  \
Then the second Rectangle in the previous cell had (gr2) as a third argument, \
and that makes the second rectangle filled in with graphic (gr2) instead of a \
solid color.\
\>", "Text"],

Cell[BoxData[
    \(\(Show[
        Graphics[{\[IndentingNewLine]Hue[0], 
            Rectangle[{0, 0}, {1.02, 1.02}], \[IndentingNewLine]Hue[0.6], 
            Rectangle[{0.6, 0.7}, {1, 
                1}]\[IndentingNewLine]}], \[IndentingNewLine]PlotRange -> 
          All, ImageSize -> {500, 400}];\)\)], "Input"],

Cell["\<\
You can further dress up a graphic with additional graphics primatives as I \
do in the next cell.\
\>", "Text"],

Cell[BoxData[{
    \(\(rect1 = 
        Line[{{0, 0}, {0, 1.05}, {1.05, 1.05}, {1.05, 0}, {0, 
              0}}];\)\), "\n", 
    \(\(\(rect2 = \[IndentingNewLine]Line[{{0.6, 0.6}, {0.6, 1}, {1, 1}, {1, 
              0.6}, {0.6, 0.6}}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Show[
        Graphics[{\[IndentingNewLine]Rectangle[{0, 0}, {1.02, 1.02}, gr1], 
            Rectangle[{0.6, 0.7}, {1, 1}, gr2], rect1, rect2}], 
        PlotRange -> All, ImageSize -> {500, 400}];\)\)}], "Input"],

Cell["\<\
The third argument given to Rectangle doesn't need to have the head Graphics. \
 Any type of Mathematica graphics can be given.  In the next cell one of the \
rectangles is given Graphics3D as a third argument.\
\>", "Text"],

Cell[BoxData[{
    \(\(\(Block[{$DisplayFunction = Identity}, \[IndentingNewLine]\(gr2 = 
            Plot3D[Sin[x] Exp[y], {x, \(-5\), 5}, {y, \(-2\), 
                2}];\)\[IndentingNewLine]];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Show[
        Graphics[{\[IndentingNewLine]Rectangle[{0, 0}, {1.02, 1.02}, gr1], 
            Rectangle[{0.6, 0.7}, {1, 1}, gr2]}], PlotRange -> All, 
        ImageSize -> {500, 400}];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Shading", "Section"],

Cell[TextData[{
  "Shading is an option for Graphics3D, SurfaceGraphics and funtions that \
return Graphics3D or SurfaceGraphics. The default setting is \
(Shading\[Rule]True) in which case polygons are colored as determined by \
simulated ",
  ButtonBox["Lighting",
    ButtonData:>"LightSources",
    ButtonStyle->"Hyperlink"],
  " or the ",
  ButtonBox["ColorFunction",
    ButtonData:>"ColorFunction",
    ButtonStyle->"Hyperlink"],
  ".  The ",
  ButtonBox["HiddenSurface",
    ButtonData:>"HiddenSurface",
    ButtonStyle->"Hyperlink"],
  " option is used to render the surface as a transparent mesh."
}], "Text",
  CellTags->"Shading"],

Cell[BoxData[{
    \(Options[SurfaceGraphics, Shading]\), "\n", 
    \(Options[Graphics3D, Shading]\)}], "Input"],

Cell[BoxData[{
    \(\(Plot3D[Exp[\(-\((x\^4 + y\^4)\)\)], {x, \(-2\), 2}, {y, \(-2\), 2}, 
        Shading \[Rule] True];\)\), "\n", 
    \(\(Plot3D[Exp[\(-\((x\^4 + y\^4)\)\)], {x, \(-2\), 2}, {y, \(-2\), 2}, 
        Shading \[Rule] False];\)\)}], "Input",
  CellTags->"Shading"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Text", "Section"],

Cell["\<\
The typical use of text is straight forward.  However, one must do some very \
tricky stuff to display framed text in Graphics or Graphics3D.  Alan Hayes \
showed how this can be done in response to a question in the MathGroup.  The \
next cell demonstrates Alan's solution.  I would elaborate on how it works, \
but I don't understand it myself.\
\>", "Text"],

Cell[BoxData[{
    \(\(\(txt2 = 
        Graphics[\[IndentingNewLine]Text[
            DisplayForm[
              FrameBox[\[IndentingNewLine]FormBox[
                  StyleBox[
                    MakeBoxes[\[Rho]\  = \ k\ r^2, 
                      TraditionalForm], \[IndentingNewLine]FontWeight \[Rule] \
"\<Bold\>", FontSize \[Rule] 24], TraditionalForm]]\[IndentingNewLine]], {5, 
              1/2}]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(Block[{$DisplayFunction = Identity}, \[IndentingNewLine]plt2 = 
          Plot[\ Sin[x], {x, 0, 2  \[Pi]}]\[IndentingNewLine]];\)\), "\n", 
    \(\(Show[{plt2, txt2}];\)\)}], "Input"],

Cell["The next cell does the same thing with Graphics3D.", "Text"],

Cell[BoxData[{
    \(\(\(txt1 = 
        Graphics3D[\[IndentingNewLine]Text[
            DisplayForm[
              FrameBox[\[IndentingNewLine]FormBox[
                  StyleBox[
                    MakeBoxes[\[Rho]\  = \ k\ r^2, 
                      TraditionalForm], \[IndentingNewLine]FontWeight \[Rule] \
"\<Bold\>", FontSize \[Rule] 24], TraditionalForm]]\[IndentingNewLine]], {3, 
              3, 0}]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(Block[{$DisplayFunction = Identity}, \[IndentingNewLine]plt1 = 
          Plot3D[Cos[x]\ Sin[y], {x, 0, 2  \[Pi]}, {y, 0, 
              2  \[Pi]}, \[IndentingNewLine]PlotPoints \[Rule] 40, 
            Mesh \[Rule] False]\[IndentingNewLine]];\)\), "\n", 
    \(\(Show[{plt1, txt1}];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ticks", "Section"],

Cell["\<\
The next line gives a plot with manually specified ticks on the horizontal \
axis.\
\>", "Text"],

Cell[BoxData[
    \(\(Plot[x\^2, {x, 0, 3}, \n\t
        Ticks \[Rule] {{1, 2, 3}, \n\t\tAutomatic}];\)\)], "Input"],

Cell["\<\
Next we have a plot with manually specified ticks where some of the ticks \
have no label.\
\>", "Text"],

Cell[BoxData[
    \(\(Plot[x\^2, {x, 0, 3}, \n\t
        Ticks \[Rule] {\n\t\t\t{{0.5, "\<\>"}, {1, 1}, {1.5, "\<\>"}, {2, 
                2}, {2.5, "\<\>"}, {3, 3}}, \n\t\tAutomatic}];\)\)], "Input"],

Cell["\<\
The next line makes a plot with manually specified ticks where some of the \
ticks have no label and the height of each tick is specified.  In this case \
one value is given for height and the tick is extended by that distance in \
the positive and negative directions.\
\>", "Text"],

Cell[BoxData[
    \(\(Plot[x\^2, {x, 0, 3}, \n\t
        Ticks \[Rule] {\n\t\t\t{{0.5, "\<\>", 0.01}, \n\t\t\t\t{1, 1, 
                0.03}, \n\t\t\t\t{1.5, "\<\>", 0.01}, \n\t\t\t\t{2, 2, 
                0.03}, \n\t\t\t\t{2.5, "\<\>", 0.01}, \n\t\t\t\t{3, 3, 
                0.03}}, \n\t\tAutomatic}];\)\)], "Input"],

Cell["\<\
The next line uses a list (of two values) for the height of the ticks.  This \
specifies the height in the positive and negative directions.\
\>", "Text"],

Cell[BoxData[
    \(\(Plot[x\^2, {x, 0, 3}, \n\t
        Ticks \[Rule] {\n\t\t\t{{0.5, "\<\>", {0.01, 0}}, \n\t\t\t\t{1, 
                1, {0.02, 0}}, \n\t\t\t\t{1.5, "\<\>", {0.01, 
                  0}}, \n\t\t\t\t{2, 
                2, {0.02, 0}}, \n\t\t\t\t{2.5, "\<\>", {0.01, 
                  0}}, \n\t\t\t\t{3, 
                3, {0.01, 0}}}, \n\t\tAutomatic}];\)\)], "Input"],

Cell["\<\
In the next line the specification a style for some ticks is given (in list \
braces) after the height specification.\
\>", "Text"],

Cell[BoxData[
    \(\(Plot[x\^2, {x, 0, 3}, \n\t
        Ticks \[Rule] {\n\t\t\t{{0.5, "\<\>", {0.01, 0}}, \n\t\t\t\t{1, 
                1, {0.02, 
                  0}, {Thickness[0.01]}}, \n\t\t\t\t{1.5, "\<\>", {0.01, 
                  0}}, \n\t\t\t\t{2, 
                2, {0.02, 
                  0}, {Thickness[0.01]}}, \n\t\t\t\t{2.5, "\<\>", {0.01, 
                  0}}, \t\t\t\t{3, 
                3, {0.02, 
                  0}, {Thickness[0.01]}}}, \n\t\tAutomatic}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Graphics primitives and directives", "MiscSection"],

Cell[TextData[{
  "In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphic primitives are nouns, and graphic directives are adjectives.  \
That is the the directives specify what the primitives look like.",
  StyleBox["\n", "Input",
    FontWeight->"Plain",
    Background->None,
    FontVariations->{"CompatibilityType"->0}],
  "\nThe graphics primitives (2D) for use in Graphics[{__}] are\n     Line, \
Point, Polygon, Text, Rectangle, Circle, Disk, Raster, RasterArray.\n\nThe \
graphics primitives (3D) for use in  Graphics3D[{__}] are\n     Line, Point, \
Polygon, Text, Cuboid.\n     \nThe directives available for specifying \
Graphics and Graphics3D primitives are:\n    Thickness, PointSize, Dashing, \
AbsoluteThickness, AbsolutePointSize, AbsoluteDashing, RGBColor, Hue, \
GrayLevel, CMYKColor.\n\nIn addition the following directives are available \
for Graphics3D primitives:\n    SurfaceColor, EdgeForm, FaceForm\n\nThe first \
argument in Graphics, or Graphics3D must be a suitable graphics primitive, or \
a list of such primatives. If a list of primitives is used, graphic \
directives can be included.  A graphics directive affects all relavent \
primitives that come after the directive until another directive is given to \
override the earlier directive.\n\nFor example in the next cell the first \
point, circle and line are drawn using the default directives.  The second \
circle and line are thicker due to the directive Thickness[0.02].  Also the \
second point is larger due to the directive PointSize[0.02]. The third point, \
circle and line are red due to the directive RGBColor[1,0,0] but the earlier \
directives for Thickness and PointSize still apply. Then for the fourth \
point, circle and line are green because the earlier color directive is \
overridden by the directive Hue[0.3]. In addition the directive \
AbsolutePointSize[20] makes the fourth point even larger than the points \
before it. However, the fourth circle and line are the same thickness as the \
third circle and line because there is no directive to override the earlier \
thickness. Finally the last circle and line are thinner due to the directive \
AbsoluteThickness[1], but they have the same color as the circle and line \
that preceeded them because the earlier directive wan not overridden.  \
Likewise the last point is the same size as the fourth point because there is \
no overridding directive.\n"
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"example", "=", 
        RowBox[{"Graphics", "[", 
          RowBox[{"{", "\[IndentingNewLine]", 
            
            RowBox[{\(Point[{0.5, 0.5}]\), ",", 
              "\[IndentingNewLine]", \(Circle[{0.5, 0.5}, 0.3]\), ",", 
              "\[IndentingNewLine]", \(Line[{{1, 0}, {1, 1}}]\), ",", 
              "\[IndentingNewLine]", 
              StyleBox[\(Thickness[0.02]\),
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[",",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[\(PointSize[0.02]\),
                FontColor->RGBColor[1, 0, 0]], ",", 
              "\[IndentingNewLine]", \(Point[{1.5, 0.5}]\), ",", 
              "\[IndentingNewLine]", \(Circle[{1.5, 0.5}, 0.3]\), ",", 
              "\[IndentingNewLine]", \(Line[{{2, 0}, {2, 1}}]\), ",", 
              "\[IndentingNewLine]", 
              StyleBox[\(RGBColor[1, 0, 0]\),
                FontColor->RGBColor[1, 0, 0]], ",", 
              "\[IndentingNewLine]", \(Point[{2.5, 0.5}]\), ",", 
              "\[IndentingNewLine]", \(Circle[{2.5, 0.5}, 0.3]\), ",", 
              "\[IndentingNewLine]", \(Line[{{3, 0}, {3, 1}}]\), ",", 
              "\[IndentingNewLine]", 
              StyleBox[\(Hue[0.3]\),
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[",",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[\(AbsolutePointSize[20]\),
                FontColor->RGBColor[1, 0, 0]], ",", 
              "\[IndentingNewLine]", \(Point[{3.5, 0.5}]\), ",", 
              "\[IndentingNewLine]", \(Circle[{3.5, 0.5}, 0.3]\), ",", 
              "\[IndentingNewLine]", \(Line[{{4, 0}, {4, 1}}]\), ",", 
              "\[IndentingNewLine]", 
              StyleBox[\(AbsoluteThickness[1]\),
                FontColor->RGBColor[1, 0, 0]], ",", 
              "\[IndentingNewLine]", \(Point[{4.5, 0.5}]\), ",", 
              "\[IndentingNewLine]", \(Circle[{4.5, 0.5}, 0.3]\), ",", 
              "\[IndentingNewLine]", \(Line[{{5, 0}, {5, 1}}]\)}], 
            "\[IndentingNewLine]", "}"}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", \(Show[example, 
        PlotRange -> {{0, 5.2}, {0, 1}}, Axes -> True, 
        AspectRatio \[Rule] Automatic, 
        ImageSize \[Rule] {600, 150}];\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
How to hide the portion of a graphic that is outside of a circle\
\>", "MiscSection"],

Cell["\<\
Sometimes one might want to display a graphic such that only the portion \
inside a circle with a certain radius is displayed. The plot of a Sin wave \
below will be used as an example where only the portion of the graphic inside \
a circle centered at the origin with radius 0.85 is displayed.\
\>", "Text"],

Cell[BoxData[
    \(\(curve = Plot[Sin[75\ t], {t, \(-1\), 1}];\)\)], "Input"],

Cell["\<\
The graphic made by the next cell is used to demonstrate how one can hide the \
portion of the above plot outside the desired circle.\
\>", "Text"],

Cell[BoxData[{
    \(\(\(circ = 
        ParametricPlot[{0.85*Cos[t], 0.85*Sin[t]}, {t, 0.03, 
            2  \[Pi] - 0.03}, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity, PlotPoints \[Rule] 9, 
          PlotDivision \[Rule] 1];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(pnts = 
        Join[Part[circ, 1, 1, 1, 
            1], \[IndentingNewLine]{{1.1, \(-0.03\)}, {1.1, \(-1.1\)}, \
{\(-1.1\), \(-1.1\)}, {\(-1.1\), 1.1}, {1.1, 1.1}, {1.1, 
              0.03}}\ \[IndentingNewLine]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(mask = 
        Graphics[{GrayLevel[0.7], Polygon[pnts]}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Show[mask, AspectRatio \[Rule] Automatic, 
        PlotRange \[Rule] {{\(-1.5\), 1.5}, {\(-1.5\), 1.5}}, 
        Axes \[Rule] True];\)\)}], "Input"],

Cell["\<\
The next input displays the mask from above on-top of the Sin wave made \
earlier.\
\>", "Text"],

Cell[BoxData[
    \(\(Show[curve, mask, AspectRatio \[Rule] Automatic, 
        PlotRange \[Rule] {{\(-1.5\), 1.5}, {\(-1.5\), 1.5}}, 
        Axes \[Rule] True];\)\)], "Input"],

Cell["\<\
The next cell makes a circle with lots of points, and ensures the mask covers \
the whole circle.\
\>", "Text"],

Cell[BoxData[{
    \(\(\(circ = 
        ParametricPlot[{0.85*Cos[t], 0.85*Sin[t]}, {t, 0, 
            2  \[Pi]}, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(pnts = 
        Join[Part[circ, 1, 1, 1, 
            1], \[IndentingNewLine]{{1.1, 
              0}, {1.1, \(-1.1\)}, {\(-1.1\), \(-1.1\)}, {\(-1.1\), 
              1.1}, {1.1, 1.1}, {1.1, 
              0}}\ \[IndentingNewLine]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(mask = 
        Graphics[{GrayLevel[0.7], Polygon[pnts]}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Show[curve, mask, AspectRatio \[Rule] Automatic, 
        PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 1}}, 
        Axes \[Rule] True];\)\)}], "Input"],

Cell["\<\
In the next cell the mask is invisible since it's the same color as the \
bacgkround.\
\>", "Text"],

Cell[BoxData[{
    \(\(\(mask = 
        Graphics[{GrayLevel[1], Polygon[pnts]}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Show[curve, mask, AspectRatio \[Rule] Automatic, 
        PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 1}}, 
        Axes \[Rule] True];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Making an animation", "MiscSection"],

Cell["\<\
When making frames for an animation it's convenient to have all the frames of \
the animation grouped together with all but the first frame closed.  The code \
in the next cell does this automatically.  This solution was sent to the \
MathGroup by  (adam.smith@hillsdale.edu).\
\>", "Text"],

Cell[BoxData[{
    \(\(Do[
        Plot[Sin[2\ \[Pi]\ \ \((t + n/25)\)], {t, 0, 1}], {n, 1, 
          25}];\)\), "\[IndentingNewLine]", 
    \(\(SelectionMove[EvaluationNotebook[], All, 
        GeneratedCell];\)\), "\[IndentingNewLine]", 
    \(FrontEndTokenExecute["\<CellGroup\>"]\), "\[IndentingNewLine]", 
    \(FrontEndTokenExecute["\<OpenCloseGroup\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The right way to plot  f'[x]", "MiscSection"],

Cell["\<\
Consider several attempts to plot the derivative of f[x] below.\
\>", "Text"],

Cell[BoxData[
    \(\(f[x_] = Sum[Sin[n\ x]/n, \ {n, 20}];\)\)], "Input"],

Cell["This first attempt doesn't work at all.", "Text"],

Cell[BoxData[
    \(\(Plot[D[f[x], x], \ {x, 0, 8}];\)\)], "Input"],

Cell["\<\
The second attempt works, but takes over 11 seconds, because the derivative \
is derived for every sample point.\
\>", "Text"],

Cell[BoxData[
    \(\(Plot[\(f'\)[x], \ {x, 0, 8}];\)\)], "Input"],

Cell["\<\
The best version is below,and takes a little more than 1 second.  It works \
much faster because the derivative is worked out only once (before the \
derivative is sampled).\
\>", "Text"],

Cell[BoxData[
    \(\(Plot[Evaluate[\(f'\)[x]], {x, 0, 8}];\)\)], "Input"]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
AutoItalicWords->{},
Magnification->1.25,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[RawData["\<\
Cell[StyleData[\"Notebook\"],
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ \"Page\"]}], \"PageNumber\"], None, Cell[
         
          TextData[ {
            ValueBox[ \"FileName\"]}], \"Header\"]}, {Cell[ 
          TextData[ {
            ValueBox[ \"FileName\"]}], \"Header\"], None, Cell[ 
          TextData[ {
            CounterBox[ \"Page\"]}], \"PageNumber\"]}},
  PageHeaderLines->{True, True},
  PrintingOptions->{\"FirstPageHeader\"->False,
  \"FacingPages\"->True},
  CellBracketOptions->{\"Color\"->RGBColor[0, 0, 0.466667]},
  StyleMenuListing->None]\
\>"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellBracketOptions->{"Color"->RGBColor[0, 0, 0.466667]},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Header Graphic (to be pasted in)", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["HeaderCell"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    Evaluatable->False,
    PageBreakBelow->False,
    ImageSize->{350, 24},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    StyleMenuListing->None],
  
  Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005N000061000`40O003h00OJgoo00Ikog?NJia[
W7>LNmh4Ool00gOoJg]c_@05Ool01GOoJke[NfnLOmh0g7oo001YOol047?oDeU6DTV]CHa1cSIc?YAJ
mgNmOomSW56<@NlfLe[g0Woo00U_oe<HBLi=JdG>=U8nU5lGMmh0fWoo001XOol00f_NH:El0005O000
16R4=Li2eVIB0g`000EXHcHaKke__FAS00El0004H:D^4DjDMmkIOol006Moo`03Nomh07`000Ql0003
>Q1l07`000=l0003CLeO_G`000Ql0003<Q1JmWoo0=Qoo`0000MVNFIjHWYVNV9jIWYRN@02IWX0269i
IWYVNV9jIWYRNFIjHWX2IWX00f9iIWYRNP02IWX2HWX2IWX00f9iHWYVN@02IWX01F9jIWYVNFIjHWX0
0VIj01=RNVIjHWYVNV9jIWUVNVIiHWYVNVIiHWYVNV9jIWYRNVIjIWURNP02IWX01F9iHWYVNVIjHWX0
0VIj00ERNFIjHWYVNFIj009RNP06IWUVNVIjHWYVNV9j0VIj00=RNVIjIWT00V9j0VIj00ARNVIjIWUR
NP9VNP03HWYVNF9j009VNP03HWYNgW@000]l0003O21l07`0009l0003CM9d0G`000Ql0009L00MKeHF
J[]VVfZjJY]V^fZj009Z^`03J]]Z^f[K009Zf`03K]]ZnfkK009^n`03K_a^nfkl009^o004Kaa^o6lL
La`3Ka`05W<mLaac?7<lLaac?G<lLcec?7LmLeac?GLlLeec?G=MMeecGGMMLeegGG=M0WMM0gMm00Eg
GGMnMgegOWMm00=gOP0=NiigOGMnNiigOWNNNiigOGNNNiigWW^NMkh017^N00Ek_W^NNiik_W^O00Ik
_P0>Nkmo_W^oNmik_gnoNmio_g_OOmmkgWnoOmmkg`Aog`03NmmoggoO009og`03OomoggoO065oo`00
00<d43P@>1000SP@00Hd4CP@=10h43PA=102>1001C@@>10h43P@=1000SP@00<d43P@=1000cP@00ld
43P@>14h43@@>10d43P@=14h43@@>10d43P@=1000SP@00Ld43P@=14h43@@>10d4@02>10013@@>10d
43P@0S@@00<h43@@>1000SP@00Td43P@>10d43PA>10d43P@=1000cP@00Ld43P@=10h43@@>10d4002
>1001C@@>10h43P@=1000SP@00@d43P@>10d408h4006=10h43@@>10d4CP?1G`000<l:TQ>O00017`0
00I41W`0O01l05`W?2h5O0000f`2O01l0003O0001B@692dlDT1a?7800T2B00A0Td2bA;=4/`94d`03
A?A8m4Sd00995003CAE9=DdD009=E@03DEIAME5e009AMP05DIIEUUFFEIME]P02EKL015WGEMMIeeGG
15Wh00aN65XHGQQN65hhGQQN>F8hHUUR>69IGUT3HUT0369iHWYVNF9jIWUVNV:IIYYVNVJJI[YZVP9V
^P06J[]Z^V[KJ[]ZffkK0f[K00=Znf[lK_/00Vkk0VlL00=_6flLK_`00W<L00A_?7<lKaac?09c?@09
Leac?G<mLeagGG=MMeegOG=M00=gO@07MiigOGNMMiikWGNNNih00W^n00AkWW^nNkik_`9k_P06Nmmo
gW_OOmikggoOEWoo0002A=<01DBcA=A4ddCCA;<014CC00]4/dCCA==4e4CCA;=4ddBcA=A4ddBc00=4
d`06A;=4e4CCA;=4ddCD0TCC00=4/dCCA=<00TCC00=4/dCDB;<00TCC00E4]4CCA;=4ddCD00A4d`06
A;=4ddCDA==4/dCD0dCC00E4e4CCA==4ddBd00=4d`03A;=4ddSD0094d`03A;=4e4CC00=4d`03A=A4
ddBc0094d`03A=A4ddBc0094d`03A=A4ddBd00A4d`0>A=A4ddBcA=A0e5B_O05d0g@SN05TB3Cg:?QP
9@Al0006:6X`eEB?B;8`nW0S17`000</JRciF8h017`000EL8b3>BAA=5Ddd009==@03DEE=EU5E00=A
MP9EUP0=DIIEUeFgEKII]eGGFMMEeeggFOMIf5hHFOP00ehH00MN>5hIGSQN>68iHUUN>@03HUT01f9i
IUURNFIjHWYVVFIj00AVVP09IY]V^VZJI[]Z^VZkI[]ZfVZj00EZf`07K_]ZnfkLJ_]^nfklK_/00Vkl
00I_6flLKaa^o7<LKc`2La`00flmLaa_?@02Lc`2Lcd02WMLLeecGGMMLeegGG=mMeegOGMM0WMm00Qg
OWNMMgigWWMmNiigWGNN0g^N00=k_W^NMkl017^n00Qo_g_NNkikggoNNmmogWoo0WoO00=ooWoOOol0
EGoo0002A;<0142B?54lDSab0TBc0210Td2BA;=4/cab@58lLCaB?790LSab@994/d2c@58lLT1b@990
LSab@74lDTBBA;=0Tcab@54lLT1bA;=0TSaA0Sab0T2B01LlLT1a?590LSab@590LT2B?790DT2BA;=4
/T1bA;=4Td1b?74lDT1b?78lLD1b0094/`09@78lLSaA@790Tcab@54lLT1b0094/`05@990DSab?590
TP02A;<013ab?34lDSaA0T2B014lDT1b@9=4/d2B?790LSaA@9=0e3SF>?LlecSF?=I8/dAY00El0005
;;50e42d@=@he`04O00017006914dcCi17`000Id01b^A?===DTECC@2CCD01E5ECEEAEE5fDGD00U5f
0UFF00aE]UFgEKII]eGGFKQEeeWhFOMIn5ggFOP4GQP2GST2HSP6HUT01fIjHUUVNF9jIWURVVIi009V
VP05JYYVVfJjJYYV^`02J[X00fZkJ]]Z^P03J]/02fkKJ]]^nf[KK_]Zo6kkJaa^o6kkK_`00VlL00Uc
6flLLaa_?7<lLaa_?G<lLcd00W<l0W<m00=gG7<mLed00W=M01EgGG=MMgecOGMnMgegOWMmNgigOGNN
MiekOW^NMiikWGNnNiik_W^NNkl00W^n00Qo_W_NNkmogg^nNmmogg_O0WoO00AoogoOOomogeEoo`00
02i4/d2BEKMZ^ehHJ[Y8ld1cCEEEUT1bA==VVV9IFMQRFFIiGSUVNUFF@79AMVJJFMMVNU5fGQQRFEWH
IYYAUT1bDGIZ^UWhGSUR>CaBGQQVVUWGIWYEUUVgIWYIf0=RF@0>IYYE]ddeIYYRFEWG@794m5Vg?59=
EFJJGQUN60=RF@0:HSTlLTBcIYYIn68iGQQ=EFZjFOP2HST06D2C@99I]fJjFMQRNEgh?98h46JJMii^
fflLB?AAUVIjIYYAMT1bEGIVVUWGIYYEUT2B00=4/`03A=@leFA800El0006>6/le4RdA==0]3cE17`0
00EH0b2>A;@lmg0T00Al00046:e954dECA@3CCD07deEDEEAEU5eDEIAUUFFDIIEUeFfEIME]eGGFKME
eeWgFMMImeghFOQJ65hGGOQN65hiGQQR>5iIHSUNF68i00=RF@08HWYVFF9iHWYRNFIjIYUVNP=VVP03
I[YVVVJk009Z^P05I[]Z^fJjJ]]Z^`05J]/01FkkJ]a^nfkkK_`00Vkk00=_76kkKa`00flL00Ec76lL
Laac?6lL009c?00=Leec?7=LLcecG7<mLeegGG=MMgegGGMnMed00gMm00IgOWMmMiekOWNNMid3Nih0
0gNNNiik_P02Nkh027^oNkik_goNNkikggnnNml2Oml017_nOmmoogoOEWoo0000?DBc@9=956JJOomE
]dBc?75Mn7oo=110TUFgLceoog<mB?Aoof9IA==0TdCCGQUoogMm@998m7MmOomN64CD@998m5FgOomo
gdSd@79956[LOomVVTBcA?=^o7ooHSU==E5EEIIooddeK_]oodBc@79==Goo>114ddde009oo`07A;=^
o7oOA==4/d2BBCD00Woo00=8m4BcDIH00Woo00U954BB@9=8lehIOomgGDCC>1000Woo00i8e42BHUUo
oe5FOomRFDCC@9=4dehIOomkWT2c0dBc00A4ddBc?=I/A`Al0007>4L<S3b@A;A4/dCC?=H017`000EL
8QR=@;8ln7@R00Al00048<i4m4dEBA@2CCD014eECCE=EE5e0U5f015AME5fEIIAUUFGEKII]UFgEMMI
]eWHFOMIf5WgGQQMn5XH009N6004HQQN>EhHGST2HST00eiIHSURF@02HUT0269jIWURNVIiHWYVVVJI
IWX4IYX01fZjIY]V^VZjJ[]ZffZj009Zf`0EJ[]ZffkKJ_]ZffkkJ_a^g6kkK_a_76kkKaa^o7<KKaac
76llLaa_?6lM009c?00BLcec?7<mLcagGG=MMeegG7=MMeecGGMmMeegOG=nMgegOWNM0WMn00UgWG]n
NiigWG^NMiikWWNnNih01G^n00]k_g_OOmikggnnNmmoogoONmmoogoO05Ioo`0002]4/dCC@98d47^n
>150/caAHSUooeFF?790DT2BOomEUS@@DEERNS`aA;<lDE5EOom4dd1b?59=5GooA==0LTBc@;<d3goo
Ka`h44CC@78lDGooDGHlDP02@780?7ooCEDlDD2C>35AMG<m>15_73`a?79EUWooIWTh<CP@Lceogc@@
>11gOCPA@;=4/c@?OomZVSPA@;<d47ooMcdd44BcA==0Tc0?OomR>3@@FMMoocPa@790/SPAGQQ^fd2b
IYXl<DCC?55AEGooA;=0LTBc?=DX/@8PSP0378m0SGPT00Al0003:4L/STCC0094/`03>=Ml07`000=l
000316/PSR2a00Al0006K00TdDdEBAA==Ddd0Tde00Y=EE5FCEEAEU5eDGIEUU6FEIME]P=E]`9Ie`06
EMMIeeWgGOQIn5Wg0ehH015N>EhHGSQR>EiHHSURFEiIHUURNF9IIWURFVIiHWYVNVIi00EVVP09J[YV
VfZjJ[YZ^fJkJ[YZ^fJk009Zf`0<K_]Zff[KK_]ZffkkJ_]^o6[kK_a_76lK16lL00=c76llLa`00W<l
00Qc?G<lLcecG7<mLeec?G=L0g=M029gOG=MMgegOGMMMgegOWMmMiigOG^NMiegWW^NMiikWW^nMiik
_g^nNkmk_WnoNkikggoNNkiogg_OOmikggoOOomogUMoo`0001m0/dBcA=<lDV[KEII0Tc`aK_aoogoO
?350TT1bOomVVSaA>35k_SaB?34`46ZkOolh4D2c@;90TWooFMLlLP02A;<013PaNgioocPA0TBc038h
4GooIYXlDDBc>11oofIj?554/dSd?790TSaALce0TcaAHUYoogMn@78h<FZkOolh<CaBIWUMn3P@>154
/gooEKI0LTBc?35c?Goo>114ddBcA=<h47ooMgh`3gMMOold44CC0TBc01<lDE6G?35kWSaB?34`46Zk
Oolh4DBc?=EXB6PSG09L8VP106`@[`04O0001f0188m4/dCCA;<leVa600Al0003J08dAg0000Al000;
D2@hlddECAA95DTdDCE==E5ECEEAE@02DGH04U6FDGIEUU6FEIME]UFgFKIEeeVhFMMImeWHFOMN65Wh
GQMJ609N6006GSUN>68iHSUNF68i169I00ERNVIiHWUVNF:J009VNP03IYUVVVJK009VVP05J[YV^fZj
I[YZ^`03J]/016ZjJ]]ZffkK0V[K00I^nfklK_]ZnfklKa/2K_`00flKKaac7002Ka`01W<LKcac76lm
Kcac?09c?@0<LcagG7=MMeecGGMMLeegGGMmLeegOGMn0WMm00agOWMmMiikOG^NNiegWW^NMkikWW^n
Nih4Nkh01g^oOkikgg_OOkmkgW_O00=og`03Oomoggoo05Eoo`0000Q4ddBcA;=0TUFFJ_]0DCPA0Woo
04AIefJJ?54h4GooLa`l<D1bEIIooflLLaaoogoO>114ddBc>15oof9J?554ddBc?55Z^goo<0llLT1b
=0moogMM>354/cPAOom^o30??55gGCaAA;=0LVIjEIHd47^NOom8m6kk=11R>Goo>354TSaBOom_77<L
Niiood2c@994/caAHWYoocPA0dBc00Ph4GMnOol`3WMnOolh4D2c0TBc00e0ddBB?79EUWooKaac77oo
Nmlh442c?=Id9004O0000g0RK09l0003O0000f@1;;54e002A;<00d3DB;9l000:O0001BR_BAE=54TE
CA@00dde0TeE00MAMU5EDGIAMUFFDIIEU`02EKH2EKL04EWGEMMImeWHFOMMn5WgGOQJ65hIGQQN>5hH
HSUN>5hiHST01F9I00QVNV9iIWYRNVIiIWYRVFIj0fJJ00UV^VZkIYYZ^fZjJ]YZ^fZjJ[/00V[K00a^
ff[KJ_]^nf[KK_aZnfklKa]^o6kkLa`4Ka`01g<LKcec76llLaac?7<m009c?005Leec?G=MLeecG002
Led00gMmMeegO@03Mgd037MnMgekWWMmMiigOGNNNiigWW^NMiikWP=k_P0?Nkmk_WnnNkikgWnoNmik
ggnoOomoggooNmmoogoO05Eoo`000dBc00=0/d1bMgh00SPa015oogMM<0moocaB>11oog^o>354/cPa
Okm0LSQAOomZfc`a0094/`0:=11oogMM>354/dCC?59In7ooGOP2HUT0<eWhOomoocPAA;<h<G=MOomV
NW^oNkhh4DBc@99=EF[K<0ioog<m<0ikOSPaEGIood2B@;<l<F[KFMLh<FlLOolh4DBcA=<lLUWGOom0
TT2CA==4/caAIYYoob`>K_aoocP@A;=4d`02A;<0342cA;<h<GoO@78hDGooK]/l<DCC@;A0d`Yl0008
@6/le4BcA;=4dd2c>=M/A`Ul000>D4Lm5DceBAA=54TECCA==DeECCEAEDeEDGIAM@9AMP9EUP05DIMI
]eFfFMME]`02FML015WgFOQImeWh0UhH00UMmehHGQQN>EhHHUUR>5hiGUT00f9I00MRNF9IIUYRNFIj
HWYVN@04IYX01fJjJYYV^VZkI[YV^fZj009Zf`05J[YZff[KJ]]^f`02J]/04FkkJ_]^o6kkJ_]^o6lL
K_]_77;lKaac76llLaa_77<mKc`00W<l0W<m01]c?7=MMcecG7MMLeegGG=MLgegGWMMMgegOWMmMiig
OW^MMiekWWNNNiikWG^NNkigWW^nNil00W^n00ek_g^nNmik_g_NOmmogW_OOmmogWoOOomog`1FOol0
000OA;=0/dCCA;<lDG<LA9=4dgooIWTd46IJIYX`3goOOolh44Bc@79N>E6F>11ooeWG?594ddBc?35g
OWoo>1000TBc02M0LU5EOomIeddeDII8m6klOolh44Bc?55Z^gooA==N67oo?550/dBc@79^o3P@OomR
FC`aDIIRFD2COom9541cA;94/fkl;0ioog^n>1400TBc00E0LTdeOom==D2B0094/`0:?79Mn7oo=11A
MWooA;=0TTBcA=<2A;<024CC@79R>E6F>11ooeWG?782A;<00ccFE8il0007O0001E1Y>=I4]4BcA=<0
0dBc00<dmfa7O0001W`000QHAcTHB?A954SdBAE=54dd0Tde00]=EE5FDEEAMTefEGIAUUFFDIME]UFF
009E]`08FMMEeeWGFMQIeeWhGOQIm`=N6003GSUR65hh009N>@03HUQR>F9I00=RF@07IWYRNVIiHWYV
NFJJIWX00VJJ00YZVVJJIYYVVfJjJ[]Z^VJkJ[YV^`9Zf`0<J[]^nf[KJ]]^nf[kK]a^nf[kK_a_76kk
0VlL00Q_6g<LKaac76lLLca_?7<L0W<m00]c?7MLLcacGG=LLcecGGMMLeegOGMM009gO@03LgegOGMn
009gO@06MgikWWMnNiegWW^N0WNN015k_W^NNkik_g^nOkikgWnoNmmo_W_ONkmogWooNmmoogoO05Mo
o`0001m4/dCCA;=0/d1bGQQEeddeOomE]caB>31ooc@?KaaoocPAA;=0/dBbK_a=5GooB?A0TT2CA;<l
<FZkOolh4@02A;<0:42B@9=ooe6F?350TS`aFMMoocaBA;<lDEhHOold43P@Lce8m42BA;<lDF9JFMMo
oe5f@78h<G<lA==ooeFG?994/caBJ_]4TgooJ[/lDD2B0TBc00@lLWooFOQ0DP94/`08?79=EGooBA@d
47ooJ[/h<@A4/`0??590/T1bK_a=5GooB?A0LTBcA==4/ccFA;=TB7@S009l000:M0=PJ42d?=I4/dCC
A;=0/dBcA=<2A;<02CSGC;1XAg`1O01h0FA6A;4m5`03B?@00dTDCAA95@02CCD02deECCE=EE5FDGEA
MU6EEGIAUUFFEIL00UFf00YI]eGGFKMIeeWgFOQImeWhGOQJ60=N6005GSUR>5hiHUUN>@06HUT01fIi
HWYVNF9jIYUVNVJI009VVP0:IY]Z^VJkJYYV^VZkJ[YZffZjJ[/4J]/016kkJ]]^nf[k0Vkl00A^nfkl
Kaa^n`E_7004Lcac77<lKc`2Lc`2Lcd01W=MMcecGG=MLeacG@9gG@03LgegGGMm009gO@9gOP0:Mgeg
WWMmMiikWW^MMiik_W^NMih3Nkh01W^oNkik_W_NOkikg`9ogP06NmmoggoOOmmoog_OEWoo0005A;<0
34CCIWYR>GooB?A0TT1bHUUIn5ghOollD@94/`0T?59IegooOolh44SdDCDlLCabGQQoocaA@;=0LTde
>35oof9J?554/d2BDEEoodTD@98lTUEfOom9541c@990LTSDA==0TdCC0Woo02Q0TT2C@99EUVIjOomI
md1AA;=0TTBcMgeooeFg?35EUcaA@;<h47ooIYXlDD2cA;=8m41bOomIecP@GQQooc`a@794/d2bA;=Z
fd1B?79Ie`9oo`03=10lLT2B00=4/`03@=@leCSG008leP05>?LleD2dA;=0d`03A;<00dCCA;=0/`02
A;<023cD?=HheccF??LleTCeA=<3B?@014dDBAE==DdD0Tde01E=EE5ECEEAMU5EDGIAUUFFDIME]UFG
EKMIeUFgFMMEeeWhFMMIn5hHFOL00ehH00AN>5hHGSUN>09R>@03GUQRFF9I009RF@06IWYRNV9IHWYV
VFIj16JJ00YV^VJJJYYV^VZkJ[YV^fZkJ]]Z^P=Zf`05K]]Zff[KJ]]^o002K_/00f[lKa]^n`02Ka`0
17;lKaac?6lL0W<L00A_?7<MLcac?@9c?004LcecG7LmLe`2Med01g=mMeegGGMmMeegOGMn009gO@06
MiigOGNNNgekWWNN0W^N00AgWW^nNkikW`=k_P04Okmk_W_ONkh2Nml01GoONmioggooOmh0Egoo0000
1d2cA==4/dCCA;<h<FZj009oo`09?350/dBc?35gGEWgOom8e42B0094/`0M=11oogoo>10lLWooB=@d
44BcOom4/cPAA==ogbP=OomgGC0@A;<lLSPAOomI]cPA@78h<GooDGHh4002>34017oo@;=4TR`>0Woo
00Pl<D2cA;<h4G<LOomVNS@@0TBc02Hh4G<LOom4dc`aJ_]c7C@?<0moog^N=10d3gNNEIHX3GooIWXd
430?NkioocPa?58l<E5fOolh<DBc>11oog^NCEEooe5f@994/dCC0dBc00E0ddBcA;=4/dCC00=4/`0<
A==4/dBcA;=4ddBcA==4/dCCA;=0/dBd0TCC00i8e4SdA?=8m4TDCAA954TeCCEA=DeEDEEAEU5e0U5f
00EEMU6FEIIE]eFf009E]`03FMMEeeWG009Im`9In003GOQJ65hH009N6006GSUN668iGSQRFF8i0V9I
00URNF9IIUURNFIjHWUVNV:IIWX016JJ00MV^VJKJ[YV^VZkJ[YZ^`06J]/00fkkJ]]^n`02J_/01Fkl
K_]^o6lLK_/00VlL00ec76lLLca_76llLca_?7<mLcac?G=MLcac?@03Led00g=LMeecG@03Mgd02gMn
MgegOGNNMgegWW^NMgigWG^NMih00W^N00AgWW^NNkik_`=k_P05Ommk_WoONmio_`02Oml01GooNmmo
ggooOml0EGoo0002A;<0442cA;=4/d1bCCEoogoO>114/dCC?79E]goOOom953ab0TBc00llDFZkNihh
DCaBHUUoofIjK_]oog^NHWUoog^nGQP00Woo00A^o4CCCAEgO@9oo`03HYU95GMM009oo`07J[YZ^goo
Oolh44SdK_`00Woo00Dh4DBcA;=0TTTD009oo`0<J]]4ddBc@990/goo?350/cPAOomk_VIj0Woo00ER
FG=MOom4/fkK009oo`0DJ]]4/c@?KaaooehHFOQoogoO?554/caAJYYcGE5fOomE]T1bA==0/`94/`0:
@==4/dBc@;=4ddBc@;=4/dCC@;<2A;<0143CA;=4/d2c0TBc00e0ddBcA==4/dSCA==4m4SdBAA<m4TD
CAE==002CCD3CED2DGH02E6EDGIEUU6GEIIE]UGGEKMEe`02FML03eWHFOQImeghFOMN65XHGQQN>EhH
HSUN>F9IGSQN>@02HUT01VIIHUURNFIjHWYRN@9VNP03IYUVNVZJ00=VVP0?J[YVVfZjI[YZ^f[KI[YZ
^f[KJ[]ZnfkKJ]]^nf[K009^o007J_]^nfklKa]^o6lLKa/00VlL00Ec76llLaa_?G<L009c?007Lcec
?7LmLeec?7=MMe`00W=M00EgOG=NMgegGGMm009gOP0>MgegOW^MMgigWG^NMiikWG^NMkikWW^nNkmo
_P9k_P07Nkmk_W_ONkiogg_NNml00goO00=oogoOOol0EGoo00002TBcA==4/dBc@;90TehhOomkWSPa
0dBc00Dd47ooOomc7D2B0094/`0V@;=0/TdD@9=4/d2BDGI8ldCD>354ddSdBAAA=E5f@;=0TUWG@;=8
m5FF?558deFGB==EUSaaA;=E]eEfCEE4TT2CA==E]dCCA;=0/P=4/`04@794ddSdEKL2A;<05dCC@798
m4BbA;=0TU5EBAA8m3ab?59=54BcDGI4/eFg@794/eVgA;=0/c`aA;800UhH00Y4/cPaA;=4dd2c@998
m3aAB?A0LP=4/`05A==4/dBcA;=4d`03A;<01DCCA;=4/dBcA=<00dBc00=4ddBcA;<014Bc00A4ddCD
B=A8l`98m003BAA95DdD00===@03CEEAEU5E009AMP0=EGIAMU6FEIIE]eFFFKME]UVgEMQIeeWgFML0
0UWh00=J65ghGQP00UhH00AN>EhhHSQR>@9RF@0;GUURFF9IHUUVFV9iIWUVNV9iIWYRVP03IYX026Jj
JYYV^fZjI[]Z^VZkJ[X2J]/02FZkJ]]Zff[KK_]ZffkkJ_]^n`02K_`01VlLK_a_6fklKaac709_700;
Laac?7<LKcac?G<lLcec?7<mLeagG@02Led2Med017=MMgegGG=n0gMm00agOW]mMgigWGNNNiekWWNN
NkikWWNnNih2Nkh03G^oOkik_W^nNmmogW^oOmmogWoONmmooWoO05Moo`000TBc00U4ddBc@79cGG<L
J[]In41bA=<00TBc00M0LUFFK_aV^W^NB?A0/`02A;<02T2CA;=4/dBc@790TdBbA;=0TdBC0T2B00i0
TdBB@9=0TTBCA;=0TTBc@9=0TT2c@994Td2C0T2B00M0LT2cA;=4/d2BA990/`03A;<01DCCA;=0TT2C
@98014Bc00M0/dBcA;=4/d2B@9=0TP02A;<0242BA9=0TT2c@794/T2C@983A;<0142c@790LT2c1DBc
00=4TdBc@;<00dBc00E4ddBcA;=4/dCC00=4/`05A==4/dBcA;=4d`03A;<01DCCA;=4/dBcA=<00TBc
00I4ddBcA?=4ddSdB=@2BA@02TdDBAE==4deCEE==E5ECEEAME5F0U6F00AEUUFGEIIE]P9E]`09EMMI
eeWGFMMIn5ggFOQMn5XH009N600BGSUN65hHGSURFEhiHSURFF8iHWURFVIiHUURNV9iIYYVNVIi16JJ
00UVVfZJI[]Z^VJjJ]YZ^f[JJ[/00f[K00Y^ff[KJ]]ZnfkkK_aZnfkkK_a^n`9_700EL_a_76lLLaa_
?7<MKcac7G<lLcec?7=MLcacGG<mLeegGG=LLeegOG=M00AgO@08MiigOGMnMiekWWMnNiigWP9kWP05
MiikWW^nNkik_`03Nkh027oONmik_goONmiogg_OOol2Oml00gooOmmoo`1DOol000E4/`04?54lDSaA
@783A;<01TCCA;=0LSaA?58lD@A4/`05A==4/dBcA;=4d`03A;<01DCCA;=4/dBcA=<00dBc00E4ddBc
A;=4/dCC00=4/`05A==4/dBcA;=4d`03A;<01DCCA;=4/dBcA=<00dBc00E4ddBcA;=4/dCC00=4/`05
A==4/dBcA;=4d`03A;<01DCCA;=4/dBcA=<00dBc00E4ddBcA;=4/dCC00=4/`05A==4/dBcA;=4d`03
A;<01DCCA;=4/dBcA=<00dBc00E4ddBcA;=4/dCC00=4/`05A==4/dBcA;=4d`03A;<01DCCA;=4/dSD
A?<014Sd00===DdDBCD00Tde00M=EE5EDEE=MU5eDGIEMP02DIH035FgEIME]UVgFMMEeeWGFMQImeWh
GOQIm`AN6006GSUN>5hhHSURF5iI169I00MRNVIjHWUVNV9iIYYVNP04IYX01VJjJY]Z^VJkJ[YV^`9Z
^`0@J]YZff[KK]]ZffkkJ]]^nf[lK]]^o6[lK_]_76klKa/2Ka`01W<LKaac76llLca_?09c?007Lcec
?7=MLcacGGLlLgd00WMM00=cGGMmMed00gMm0WMn00MgWGMnMgekWGNNNiigW@02Nih00gNnNiik_`03
Nkh01gnoNkikggoNNmmogg_N009og`9oo`03Ommoogoo05Aoo`000814/dCDA;=4e4BcA=A4/dCDA;=4
e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4
e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4
e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4
e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4e4BcA=A4/dCDA;=4e4BcA=A4/dSD0TCC
00A8e4SdB?E9509=5008BAE==E4eCEEAEDeEDGIEMP9AMP08DIIEUUFGEKII]UFgFMMEe`9Ie`05FOMM
meWhGOQJ6003GQP01V8iGSQN>F8iHUUN>@=RF@06IUURNFIJHWUVNV:I0VIj00UVVFJJIYYZVVJjIYYV
^VJkJ[X00VZk00=ZfV[KJ[/00f[K01A^nf[KK_aZffkkK_a[6fkkK_a_6flLLaa_77<LKaac?6llLaa_
77<l0W<m00Ac?7<mMcac?@EcG@0@MgegGGMmMeigOGMnMgegWGMnMiikWWNNNiikWG^NMkh2Nih3Nkh0
2G_OOkik_W_NNkmogW^oOmikg`02Oml00gooOmmog`1FOol0008/3P04<0h/3R`><0h2;0h0130>;0h/
3S0>0R`>00@`3R`>;0h`3P8/3P04<0h/3R`><0h2;0h0130>;0h/3S0>0R`>00@`3R`>;0h`3P8/3P04
<0h/3R`><0h2;0h0130>;0h/3S0>0R`>00@`3R`>;0h`3P8/3P04<0h/3R`><0h2;0h0130>;0h/3S0>
0R`>00@`3R`>;0h`3P8/3P04<0h/3R`><0h2;0h0130>;0h/3S0>0R`>00@`3R`>;0h`3P8/3P04<0h/
3R`><0h2;0h0130>;0h/3S0>0R`>00@`3R`>;0h`3P8/3P04<0h/3R`><0h2;0h0130>;0h/3S0>0R`>
00@`3R`>;0h`3P8/3P05<0l`3S0?<0ld3`03=102>103>342?5400cab@790TP02@9800dBc@;=4d`02
A=<2B?@3BA@04TddBCE==DeDCEEAEDeeDEIAME6FDGIEUU6FEKIE]eFfEKMIeP9Ee`07FMMImeWgFOQI
meghFQP015hH0ehh00AR>EiHHUUNF@=RF@9RN@05IWURNVJIIWYVV@03IYX3I[X016ZkI[YZ^f[J0V[K
00YZfV[KJ_]^nf[kK_]^o6lKK_a_6`=_700KLca_?7<LKcac?G<lLeac?7=MLeacGGMmLeegOG=mMgec
OGMnMiegOGNNNiigWG^nMiik_WNn009k_P07Nmik_goNNmikggoOOoh0Dgoo0000

\
\>"], "Graphics",
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {Inherited, 0}},
    Evaluatable->False,
    ImageSize->{350, 24},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{25, 0}, {0, 5}},
    PageBreakBelow->False,
    LineSpacing->{0, 37},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->36,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{9, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    ShowCellBracket->False,
    CellMargins->{{60, 0}, {0, 5}},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{9, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiscSection"],
    CellFrame->{{0, 0}, {0, 1}},
    CellDingbat->None,
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{25, 0}, {0, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->5},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->{{8, 4}, {0, 4}},
    LineSpacing->{0, 22},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.6, 0.149996, 0.6]],
  
  Cell[StyleData["MiscSection", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["MiscSection", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["MiscSection", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 1}},
    CellDingbat->None,
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{25, 0}, {0, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->5},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->{{8, 4}, {0, 4}},
    LineSpacing->{0, 22},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.4, 0.149996, 0.149996]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->None,
    ShowCellBracket->False,
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{45, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 45},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {6, 40}},
    FontSize->12]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellFrame->{{0, 0}, {0, 0.25}},
    CellDingbat->None,
    ShowCellBracket->False,
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{60, 0}, {8, 8}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CellFrameMargins->{{8, 4}, {0, 4}},
    LineSpacing->{0, 22},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->None,
    CellMargins->{{22, 0}, {4, 20}},
    FontSize->11]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    ShowCellBracket->False,
    CellMargins->{{60, 0}, {5, 5}},
    TextJustification->0,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 1},
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    LineSpacing->{1, 3},
    FontFamily->"Times New Roman"]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowCellBracket->False,
    CellMargins->{{60, 0}, {5, 5}},
    LineSpacing->{1, 0},
    ParagraphSpacing->{0, 1},
    FontFamily->"Times New Roman",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->True,
    CellMargins->{{60, 20}, {0, 0}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0.6, 0.2, 0],
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[1, 0.975998, 0.949996]],
  
  Cell[StyleData["Input", "Printout"],
    CellFrame->True,
    CellMargins->{{37, 0}, {6, 6}}]
  }, Open  ]],
  
  Cell[StyleData["InlineInput"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{60, 20}, {10, 0}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0, 0.500008, 0.6],
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Printout"],
    CellFrame->False,
    CellMargins->{{37, 0}, {6, 2}},
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{60, 20}, {0, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellFrameColor->RGBColor[0, 0.6, 0.6],
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageSize->{250, 250}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellFrame->False,
    CellMargins->{{37, 0}, {6, 2}},
    ImageSize->{250, 250},
    ImageMargins->{{28, Inherited}, {Inherited, 0}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->11,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{72, 20}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{44, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayText"],
    CellFrame->0.5,
    CellMargins->{{60, 20}, {15, 5}},
    LineSpacing->{0, 12},
    ParagraphSpacing->{0, 6},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontSlant->"Plain",
    Background->RGBColor[1, 1, 0.8]],
  
  Cell[StyleData["DisplayText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{60, Inherited}, {0, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    ShowCellLabel->False,
    CellFrameColor->RGBColor[0, 0.6, 0.6],
    CounterIncrements->"Graphics",
    ImageSize->{250, 250},
    Background->RGBColor[1, 0.900008, 0.900008]],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellFrame->False,
    CellMargins->{{37, Inherited}, {6, 2}},
    ImageSize->{250, 250},
    ImageMargins->{{28, Inherited}, {Inherited, 0}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder objects in \
palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles of most \
cells.  If a cell's FormatType matches the name of one of the styles defined \
below, then that style is applied between the cell's style and its own \
options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation package. These \
styles serve to make visible otherwise invisible tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "ColorFunction"->{
    Cell[14619, 402, 364, 7, 50, "Text",
      CellTags->"ColorFunction"]},
  "ColorFunctionScaling"->{
    Cell[15982, 440, 1077, 19, 146, "Text",
      CellTags->"ColorFunctionScaling"]},
  "EdgeForm"->{
    Cell[20605, 562, 94, 1, 31, "Text",
      CellTags->"EdgeForm"]},
  "HiddenSurface"->{
    Cell[30862, 850, 666, 14, 88, "Text",
      CellTags->"HiddenSurface"]},
  "Mesh"->{
    Cell[35982, 977, 229, 5, 50, "Text",
      CellTags->"Mesh"]},
  "MeshRange"->{
    Cell[37350, 1016, 615, 10, 88, "Text",
      CellTags->"MeshRange"]},
  "Offset"->{
    Cell[39029, 1058, 551, 15, 50, "Text",
      CellTags->"Offset"]},
  "Scaled"->{
    Cell[40773, 1105, 84, 1, 31, "Text",
      CellTags->"Scaled"]},
  "PolygonIntersections"->{
    Cell[45653, 1234, 155, 4, 31, "Text",
      CellTags->"PolygonIntersections"]},
  "Rectangle"->{
    Cell[47387, 1295, 591, 11, 109, "Text",
      CellTags->"Rectangle"]},
  "Shading"->{
    Cell[51070, 1387, 642, 18, 69, "Text",
      CellTags->"Shading"],
    Cell[51831, 1411, 282, 5, 63, "Input",
      CellTags->"Shading"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"ColorFunction", 106266, 2857},
  {"ColorFunctionScaling", 106370, 2860},
  {"EdgeForm", 106472, 2863},
  {"HiddenSurface", 106563, 2866},
  {"Mesh", 106652, 2869},
  {"MeshRange", 106736, 2872},
  {"Offset", 106824, 2875},
  {"Scaled", 106909, 2878},
  {"PolygonIntersections", 107006, 2881},
  {"Rectangle", 107107, 2884},
  {"Shading", 107197, 2887}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 30, 0, 35, "Section"],
Cell[1809, 55, 504, 9, 69, "Text"],
Cell[2316, 66, 595, 12, 103, "Input"],
Cell[2914, 80, 333, 5, 50, "Text"],
Cell[3250, 87, 232, 6, 54, "Input"],
Cell[3485, 95, 450, 7, 69, "Text"],
Cell[3938, 104, 232, 6, 54, "Input"],
Cell[4173, 112, 382, 6, 69, "Text"],
Cell[4558, 120, 229, 6, 40, "Input"],
Cell[4790, 128, 481, 12, 40, "Input"],
Cell[5274, 142, 403, 6, 69, "Text"],
Cell[5680, 150, 489, 12, 40, "Input"],
Cell[6172, 164, 369, 6, 69, "Text"],
Cell[6544, 172, 370, 8, 50, "Text"],
Cell[6917, 182, 538, 12, 83, "Input"],
Cell[7458, 196, 124, 3, 31, "Text"],
Cell[7585, 201, 534, 12, 83, "Input"],
Cell[8122, 215, 357, 6, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8516, 226, 28, 0, 35, "Section"],
Cell[8547, 228, 560, 11, 69, "Text"],
Cell[9110, 241, 111, 2, 40, "Input"],
Cell[9224, 245, 533, 9, 108, "Text"],
Cell[9760, 256, 326, 7, 61, "Input"],
Cell[10089, 265, 364, 8, 110, "Text"],
Cell[10456, 275, 149, 2, 61, "Input"],
Cell[10608, 279, 125, 4, 51, "Text"],
Cell[10736, 285, 151, 2, 61, "Input"],
Cell[10890, 289, 263, 8, 51, "Text"],
Cell[11156, 299, 386, 8, 61, "Input"],
Cell[11545, 309, 482, 17, 290, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12064, 331, 31, 0, 35, "Section"],
Cell[12098, 333, 75, 0, 31, "Text"],
Cell[12176, 335, 301, 5, 103, "Input"],
Cell[12480, 342, 417, 9, 50, "Text"],
Cell[12900, 353, 248, 5, 82, "Input"],
Cell[13151, 360, 220, 6, 31, "Text"],
Cell[13374, 368, 255, 5, 82, "Input"],
Cell[13632, 375, 598, 13, 128, "Text"],
Cell[14233, 390, 314, 5, 124, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14584, 400, 32, 0, 35, "Section"],
Cell[14619, 402, 364, 7, 50, "Text",
  CellTags->"ColorFunction"],
Cell[14986, 411, 213, 4, 61, "Input"],
Cell[15202, 417, 236, 4, 82, "Input"],
Cell[15441, 423, 243, 4, 50, "Text"],
Cell[15687, 429, 216, 4, 61, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15940, 438, 39, 0, 35, "Section"],
Cell[15982, 440, 1077, 19, 146, "Text",
  CellTags->"ColorFunctionScaling"],
Cell[17062, 461, 272, 4, 61, "Input"],
Cell[17337, 467, 272, 4, 61, "Input"],
Cell[17612, 473, 280, 5, 50, "Text"],
Cell[17895, 480, 425, 9, 124, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18357, 494, 30, 0, 35, "Section"],
Cell[18390, 496, 49, 1, 40, "Input"],
Cell[18442, 499, 356, 6, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18835, 510, 34, 0, 35, "Section"],
Cell[18872, 512, 573, 11, 128, "Text"],
Cell[19448, 525, 183, 3, 102, "Input"],
Cell[19634, 530, 435, 10, 50, "Text"],
Cell[20072, 542, 342, 8, 102, "Input"],
Cell[20417, 552, 121, 3, 31, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20575, 560, 27, 0, 35, "Section"],
Cell[20605, 562, 94, 1, 31, "Text",
  CellTags->"EdgeForm"],
Cell[20702, 565, 46, 1, 40, "Input"],
Cell[20751, 568, 679, 13, 138, "Text"],
Cell[21433, 583, 108, 2, 40, "Input"],
Cell[21544, 587, 109, 3, 31, "Text"],
Cell[21656, 592, 120, 2, 40, "Input"],
Cell[21779, 596, 103, 3, 31, "Text"],
Cell[21885, 601, 134, 2, 40, "Input"],
Cell[22022, 605, 107, 3, 31, "Text"],
Cell[22132, 610, 179, 3, 61, "Input"],
Cell[22314, 615, 113, 3, 31, "Text"],
Cell[22430, 620, 294, 5, 103, "Input"],
Cell[22727, 627, 164, 3, 31, "Text"],
Cell[22894, 632, 125, 2, 61, "Input"],
Cell[23022, 636, 73, 0, 31, "Text"],
Cell[23098, 638, 130, 3, 40, "Input"],
Cell[23231, 643, 422, 11, 54, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23690, 659, 33, 0, 35, "Section"],
Cell[23726, 661, 507, 10, 129, "Text"],
Cell[24236, 673, 889, 20, 355, "Input"],
Cell[25128, 695, 316, 6, 70, "Text"],
Cell[25447, 703, 786, 16, 376, "Input"],
Cell[26236, 721, 205, 4, 50, "Text"],
Cell[26444, 727, 50, 1, 40, "Input"],
Cell[26497, 730, 692, 13, 148, "Text"],
Cell[27192, 745, 78, 1, 40, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27307, 751, 29, 0, 35, "Section"],

Cell[CellGroupData[{
Cell[27361, 755, 161, 4, 81, "Subsubsection"],
Cell[27525, 761, 185, 4, 50, "Text"],
Cell[27713, 767, 458, 9, 124, "Input"],
Cell[28174, 778, 172, 3, 31, "Text"],
Cell[28349, 783, 294, 4, 82, "Input"],
Cell[28646, 789, 172, 3, 31, "Text"],
Cell[28821, 794, 441, 8, 124, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29299, 807, 202, 5, 81, "Subsubsection"],
Cell[29504, 814, 186, 4, 50, "Text"],
Cell[29693, 820, 1085, 22, 355, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[30827, 848, 32, 0, 35, "Section"],
Cell[30862, 850, 666, 14, 88, "Text",
  CellTags->"HiddenSurface"],
Cell[31531, 866, 246, 4, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31814, 875, 31, 0, 35, "Section"],
Cell[31848, 877, 389, 6, 69, "Text"],
Cell[32240, 885, 361, 5, 124, "Input"],
Cell[32604, 892, 389, 7, 103, "Input"],
Cell[32996, 901, 624, 9, 88, "Text"],
Cell[33623, 912, 213, 3, 82, "Input"],
Cell[33839, 917, 253, 4, 50, "Text"],
Cell[34095, 923, 185, 4, 31, "Text"],
Cell[34283, 929, 158, 2, 61, "Input"],
Cell[34444, 933, 320, 5, 50, "Text"],
Cell[34767, 940, 159, 2, 61, "Input"],
Cell[34929, 944, 174, 4, 31, "Text"],
Cell[35106, 950, 198, 3, 61, "Input"],
Cell[35307, 955, 295, 5, 50, "Text"],
Cell[35605, 962, 138, 3, 40, "Input"],
Cell[35746, 967, 162, 3, 61, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35945, 975, 34, 0, 35, "Section"],
Cell[35982, 977, 229, 5, 50, "Text",
  CellTags->"Mesh"],
Cell[36214, 984, 256, 4, 61, "Input"],
Cell[36473, 990, 232, 4, 50, "Text"],
Cell[36708, 996, 292, 4, 61, "Input"],
Cell[37003, 1002, 279, 7, 50, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37319, 1014, 28, 0, 35, "Section"],
Cell[37350, 1016, 615, 10, 88, "Text",
  CellTags->"MeshRange"],
Cell[37968, 1028, 357, 6, 104, "Input"],
Cell[38328, 1036, 298, 5, 50, "Text"],
Cell[38629, 1043, 280, 5, 82, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38946, 1053, 33, 0, 35, "Section"],
Cell[38982, 1055, 44, 1, 40, "Input"],
Cell[39029, 1058, 551, 15, 50, "Text",
  CellTags->"Offset"],
Cell[39583, 1075, 1187, 28, 208, "Input"],
Cell[40773, 1105, 84, 1, 31, "Text",
  CellTags->"Scaled"],
Cell[40860, 1108, 44, 1, 40, "Input"],
Cell[40907, 1111, 344, 6, 50, "Text"],
Cell[41254, 1119, 1044, 25, 166, "Input"],
Cell[42301, 1146, 580, 13, 69, "Text"],
Cell[42884, 1161, 1571, 39, 229, "Input"],
Cell[44458, 1202, 131, 3, 31, "Text"],
Cell[44592, 1207, 982, 20, 208, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45611, 1232, 39, 0, 35, "Section"],
Cell[45653, 1234, 155, 4, 31, "Text",
  CellTags->"PolygonIntersections"],

Cell[CellGroupData[{
Cell[45833, 1242, 74, 1, 40, "Input"],
Cell[45910, 1245, 121, 3, 32, "Output"]
}, Open  ]],
Cell[46046, 1251, 268, 5, 50, "Text"],
Cell[46317, 1258, 345, 6, 103, "Input"],
Cell[46665, 1266, 162, 3, 31, "Text"],
Cell[46830, 1271, 64, 1, 40, "Input"],
Cell[46897, 1274, 129, 3, 31, "Text"],
Cell[47029, 1279, 70, 1, 40, "Input"],
Cell[47102, 1282, 124, 3, 31, "Text"],
Cell[47229, 1287, 90, 1, 40, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47356, 1293, 28, 0, 35, "Section"],
Cell[47387, 1295, 591, 11, 109, "Text",
  CellTags->"Rectangle"],
Cell[47981, 1308, 288, 7, 112, "Input"],
Cell[48272, 1317, 277, 5, 50, "Text"],
Cell[48552, 1324, 221, 4, 82, "Input"],
Cell[48776, 1330, 589, 9, 88, "Text"],
Cell[49368, 1341, 318, 6, 124, "Input"],
Cell[49689, 1349, 122, 3, 31, "Text"],
Cell[49814, 1354, 503, 10, 166, "Input"],
Cell[50320, 1366, 234, 4, 50, "Text"],
Cell[50557, 1372, 447, 8, 166, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51041, 1385, 26, 0, 35, "Section"],
Cell[51070, 1387, 642, 18, 69, "Text",
  CellTags->"Shading"],
Cell[51715, 1407, 113, 2, 61, "Input"],
Cell[51831, 1411, 282, 5, 63, "Input",
  CellTags->"Shading"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52150, 1421, 23, 0, 35, "Section"],
Cell[52176, 1423, 370, 6, 69, "Text"],
Cell[52549, 1431, 644, 13, 229, "Input"],
Cell[53196, 1446, 66, 0, 31, "Text"],
Cell[53265, 1448, 763, 15, 250, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54065, 1468, 24, 0, 35, "Section"],
Cell[54092, 1470, 106, 3, 31, "Text"],
Cell[54201, 1475, 116, 2, 83, "Input"],
Cell[54320, 1479, 114, 3, 31, "Text"],
Cell[54437, 1484, 201, 3, 104, "Input"],
Cell[54641, 1489, 293, 5, 50, "Text"],
Cell[54937, 1496, 321, 5, 209, "Input"],
Cell[55261, 1503, 164, 3, 31, "Text"],
Cell[55428, 1508, 389, 7, 209, "Input"],
Cell[55820, 1517, 141, 3, 31, "Text"],
Cell[55964, 1522, 501, 10, 188, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[56502, 1537, 57, 0, 35, "MiscSection"],
Cell[56562, 1539, 2442, 38, 542, "Text"],
Cell[59007, 1579, 2313, 45, 502, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[61357, 1629, 95, 2, 35, "MiscSection"],
Cell[61455, 1633, 318, 5, 50, "Text"],
Cell[61776, 1640, 78, 1, 40, "Input"],
Cell[61857, 1643, 157, 3, 31, "Text"],
Cell[62017, 1648, 879, 18, 229, "Input"],
Cell[62899, 1668, 106, 3, 31, "Text"],
Cell[63008, 1673, 177, 3, 40, "Input"],
Cell[63188, 1678, 121, 3, 31, "Text"],
Cell[63312, 1683, 828, 18, 229, "Input"],
Cell[64143, 1703, 109, 3, 31, "Text"],
Cell[64255, 1708, 297, 6, 82, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[64589, 1719, 42, 0, 35, "MiscSection"],
Cell[64634, 1721, 300, 5, 50, "Text"],
Cell[64937, 1728, 374, 7, 103, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[65348, 1740, 51, 0, 35, "MiscSection"],
Cell[65402, 1742, 87, 2, 31, "Text"],
Cell[65492, 1746, 73, 1, 40, "Input"],
Cell[65568, 1749, 55, 0, 31, "Text"],
Cell[65626, 1751, 67, 1, 40, "Input"],
Cell[65696, 1754, 136, 3, 31, "Text"],
Cell[65835, 1759, 66, 1, 40, "Input"],
Cell[65904, 1762, 197, 4, 50, "Text"],
Cell[66104, 1768, 74, 1, 40, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

